@@ -19,6 +19,7 @@
 #include "fullcommonusewidget.h"
 #include <QDesktopWidget>
 #include "src/Style/style.h"
+#include "src/UtilityFunction/utility.h"
 #include <QDebug>
 
 FullCommonUseWidget::FullCommonUseWidget(QWidget *parent) :
@@ -36,33 +37,77 @@ void FullCommonUseWidget::initUi()
 {
     this->setWindowFlags(Qt::CustomizeWindowHint | Qt::FramelessWindowHint);
     this->setAttribute(Qt::WA_StyledBackground,true);
-    this->setStyleSheet("border:0px;background:transparent;");
     this->setSizePolicy(QSizePolicy::Fixed,QSizePolicy::Fixed);
     this->setFixedSize(Style::MainViewWidWidth,
                        Style::AppListWidHeight);
-
+    this->setFocusPolicy(Qt::NoFocus);
     QHBoxLayout* mainLayout=new QHBoxLayout;
-//    mainLayout->setContentsMargins(Style::LeftWidWidth,0,0,0);
     mainLayout->setContentsMargins(0,0,0,0);
     this->setLayout(mainLayout);
     m_spaceItem=new QSpacerItem(40,20,QSizePolicy::Expanding,QSizePolicy::Fixed);
     mainLayout->addItem(m_spaceItem);
+    m_scrollArea=new ScrollArea;
+    m_scrollAreaWid=new ScrollAreaWid;
+    m_scrollAreaWid->setAttribute(Qt::WA_TranslucentBackground);
+    m_scrollArea->setFixedSize(Style::AppListWidWidth,this->height());
+    m_scrollArea->setWidget(m_scrollAreaWid);
+    m_scrollArea->setWidgetResizable(true);
+    m_scrollAreaWidLayout=new QVBoxLayout;
+    m_scrollAreaWidLayout->setContentsMargins(0,0,0,0);
+    m_scrollAreaWidLayout->setSpacing(10);
+    m_scrollAreaWid->setLayout(m_scrollAreaWidLayout);
+    mainLayout->addWidget(m_scrollArea);
 
     m_ukuiMenuInterface=new UkuiMenuInterface;
 
     initAppListWidget();
     fillAppList();
+
+    flag = true;
+    //翻页灵敏度时间调节
+    time = new QTimer(this);
+    connect(time,&QTimer::timeout,[=](){
+        if(flag == false)
+        {
+            flag = true;
+            time->stop();
+        }
+    });
 }
 
 void FullCommonUseWidget::initAppListWidget()
 {
     m_listView=new FullListView(this,0);
-    m_listView->setFixedSize(this->width()-Style::LeftWidWidth,this->height());
-    QHBoxLayout *mainLayout=qobject_cast<QHBoxLayout*>(this->layout());
-    mainLayout->insertWidget(1,m_listView);
+//    m_listView->setFixedSize(this->width()-Style::LeftWidWidth+3,this->height());
+//    QHBoxLayout *mainLayout=qobject_cast<QHBoxLayout*>(this->layout());
+//    mainLayout->insertWidget(1,m_listView);
+    m_scrollAreaWidLayout->addWidget(m_listView);
     connect(m_listView,&FullListView::sendItemClickedSignal,this,&FullCommonUseWidget::execApplication);
     connect(m_listView,&FullListView::sendUpdateAppListSignal,this,&FullCommonUseWidget::updateListViewSlot);
     connect(m_listView,&FullListView::sendHideMainWindowSignal,this,&FullCommonUseWidget::sendHideMainWindowSignal);
+    connect(m_listView,&FullListView::sendSetslidebar,this,&FullCommonUseWidget::onSetSlider);
+}
+
+void FullCommonUseWidget::resizeScrollAreaControls()
+{
+    QLayoutItem* widItem=m_scrollAreaWidLayout->itemAt(0);
+    QWidget* wid=widItem->widget();
+    FullListView* listview=qobject_cast<FullListView*>(wid);
+    listview->adjustSize();
+    int dividend=(m_scrollArea->width()-Style::SliderSize)/Style::AppListGridSizeWidth;
+    int rowcount=0;
+    if(listview->model()->rowCount()%dividend>0)
+    {
+        rowcount=listview->model()->rowCount()/dividend+1;
+    }
+    else
+    {
+        rowcount=listview->model()->rowCount()/dividend;
+
+    }
+
+    listview->setFixedSize(m_scrollArea->width()-Style::SliderSize+1,listview->gridSize().height()*rowcount);
+    m_scrollArea->widget()->adjustSize();
 }
 
 void FullCommonUseWidget::fillAppList()
@@ -71,6 +116,7 @@ void FullCommonUseWidget::fillAppList()
     Q_FOREACH(QString desktopfp,UkuiMenuInterface::allAppVector)
         m_data.append(desktopfp);
     m_listView->addData(m_data);
+    resizeScrollAreaControls();
 }
 
 /**
@@ -79,10 +125,42 @@ void FullCommonUseWidget::fillAppList()
 void FullCommonUseWidget::execApplication(QString desktopfp)
 {
     Q_EMIT sendHideMainWindowSignal();
-    GDesktopAppInfo * desktopAppInfo=g_desktop_app_info_new_from_filename(desktopfp.toLocal8Bit().data());
-    g_app_info_launch(G_APP_INFO(desktopAppInfo),nullptr, nullptr, nullptr);
-    g_object_unref(desktopAppInfo);}
+    execApp(desktopfp);
+}
 
+void FullCommonUseWidget::selectFirstItem()
+{
+  //  this->focusNextChild();
+    qDebug() << "void FullCommonUseWidget::selectFirstItem()";
+    m_listView->setCurrentIndex(m_listView->model()->index(0,0));
+}
+
+void FullCommonUseWidget::selectFirstItemTab()
+{
+    this->setFocus();
+    if(m_listView->currentIndex().row() == -1)
+    {
+        m_listView->setCurrentIndex(m_listView->model()->index(0,0));
+    }
+}
+
+void FullCommonUseWidget::onSetSlider(int value)
+{
+//    if(flag)
+//    {
+//        flag = false;
+//        time->start(100);
+        if(value == 0)
+        {
+            m_scrollArea->verticalScrollBar()->setValue(0);
+        }
+        else
+        {
+            int curvalue = m_scrollArea->verticalScrollBar()->value();
+            m_scrollArea->verticalScrollBar()->setValue(curvalue + value);
+        }
+//    }
+}
 /**
  * 更新应用列表
  */
@@ -94,7 +172,7 @@ void FullCommonUseWidget::updateListViewSlot()
 void FullCommonUseWidget::updateListView()
 {
     m_data.clear();
-    Q_FOREACH(QString desktopfp,m_ukuiMenuInterface->getAllApp())
+    Q_FOREACH(QString desktopfp,m_ukuiMenuInterface->getAllClassification())
         m_data.append(desktopfp);
     m_listView->updateData(m_data);
 }
@@ -103,7 +181,8 @@ void FullCommonUseWidget::repaintWidget()
 {
     this->setFixedSize(Style::MainViewWidWidth,
                        Style::AppListWidHeight);
-    this->layout()->removeWidget(m_listView);
+    m_scrollArea->setFixedSize(Style::AppListWidWidth,this->height());
+    m_scrollAreaWidLayout->removeWidget(m_listView);
     m_listView->setParent(nullptr);
     delete m_listView;
     initAppListWidget();
@@ -117,7 +196,7 @@ void FullCommonUseWidget::widgetMakeZero()
 
 void FullCommonUseWidget::moveScrollBar(int type)
 {
-    int height=QApplication::primaryScreen()->geometry().height();
+    int height=Style::primaryScreenHeight;
     if(type==0)
         m_listView->verticalScrollBar()->setSliderPosition(m_listView->verticalScrollBar()->sliderPosition()-height*100/1080);
     else
