@@ -36,6 +36,7 @@
 #include "src/RightClickMenu/rightclickmenu.h"
 #include "src/UtilityFunction/fulllistview.h"
 #include "src/Style/style.h"
+#include "src/UtilityFunction/scrollarea.h"
 
 class FullCommonUseWidget : public QWidget
 {
@@ -64,11 +65,17 @@ public:
      */
     void moveScrollBar(int type);
 
+    FullListView* m_listView=nullptr;
+
 private:
     UkuiMenuInterface* m_ukuiMenuInterface=nullptr;
-    FullListView* m_listView=nullptr;
     QStringList m_data;
     QSpacerItem *m_spaceItem=nullptr;
+    ScrollArea* m_scrollArea=nullptr;
+    ScrollAreaWid* m_scrollAreaWid=nullptr;
+    QVBoxLayout* m_scrollAreaWidLayout=nullptr;
+    bool flag;
+    QTimer *time = nullptr;
 
 protected:
     /**
@@ -83,6 +90,7 @@ protected:
      * @brief fill application list
      */
     void fillAppList();
+    void resizeScrollAreaControls();
 
 public Q_SLOTS:
     /**
@@ -95,6 +103,12 @@ public Q_SLOTS:
      */
     void updateListViewSlot();
 
+    void onSetSlider(int value);
+
+    void selectFirstItem();
+
+    void selectFirstItemTab();
+
 Q_SIGNALS:
     /**
      * @brief Send a hidden main window signal to the MainViewWidget
