@@ -38,9 +38,8 @@ FullFunctionWidget::~FullFunctionWidget()
 void FullFunctionWidget::initUi()
 {
     this->setWindowFlags(Qt::CustomizeWindowHint | Qt::FramelessWindowHint);
-    this->setAttribute(Qt::WA_StyledBackground,true);
-    this->setStyleSheet("border:0px;background:transparent;");
     this->setSizePolicy(QSizePolicy::Fixed,QSizePolicy::Fixed);
+    this->setAttribute(Qt::WA_TranslucentBackground);
     m_applistWid=new QWidget(this);
     m_iconListWid=new QWidget(this);
     this->setFixedSize(Style::MainViewWidWidth,
@@ -51,8 +50,6 @@ void FullFunctionWidget::initUi()
     QHBoxLayout* mainLayout=new QHBoxLayout;
     mainLayout->setContentsMargins(0,0,0,0);
     mainLayout->setSpacing(0);
-    m_applistWid->setStyleSheet("border:0px;background:transparent;");
-    m_iconListWid->setStyleSheet("border:0px;background:transparent");
     mainLayout->addWidget(m_iconListWid);
     mainLayout->addWidget(m_applistWid);
     this->setLayout(mainLayout);
@@ -61,6 +58,17 @@ void FullFunctionWidget::initUi()
 
     initAppListWidget();
     initIconListWidget();
+
+    flag = true;
+    //翻页灵敏度时间调节
+    time = new QTimer(this);
+    connect(time,&QTimer::timeout,[=](){
+        if(flag == false)
+        {
+            flag = true;
+            time->stop();
+        }
+    });
 }
 
 /**
@@ -73,7 +81,8 @@ void FullFunctionWidget::initAppListWidget()
     m_applistWid->setLayout(layout);
 
     m_scrollArea=new ScrollArea;
-    m_scrollAreaWid=new QWidget;
+    m_scrollAreaWid=new ScrollAreaWid;
+    m_scrollAreaWid->setAttribute(Qt::WA_TranslucentBackground);
     m_scrollArea->setFixedSize(m_applistWid->width(),m_applistWid->height());
     m_scrollArea->setWidget(m_scrollAreaWid);
     m_scrollArea->setWidgetResizable(true);
@@ -84,6 +93,7 @@ void FullFunctionWidget::initAppListWidget()
     layout->addWidget(m_scrollArea);
     connect(m_scrollArea->verticalScrollBar(),&QScrollBar::valueChanged,
             this,&FullFunctionWidget::valueChangedSlot);
+    m_appListBottomSpacer=new QSpacerItem(20,40,QSizePolicy::Fixed,QSizePolicy::Expanding);
     fillAppList();
 }
 
@@ -162,14 +172,13 @@ void FullFunctionWidget::fillAppList()
         insertClassificationBtn("Others");
         insertAppList(otherlist);
     }
-
+    m_scrollAreaWidLayout->addItem(m_appListBottomSpacer);
     resizeScrollAreaControls();
 }
 
 void FullFunctionWidget::insertClassificationBtn(QString category)
 {
-    PushButton* classificationbtn=new PushButton(this,category,m_scrollArea->width()-12,30,2);
-//    classificationbtn->setFixedSize(m_scrollArea->width()-12,25);
+    SplitBarFrame* classificationbtn=new SplitBarFrame(this,category,m_scrollArea->width()-12,30,2);
     m_scrollAreaWidLayout->addWidget(classificationbtn);
     m_classificationList.append(category);
 
@@ -178,6 +187,13 @@ void FullFunctionWidget::insertClassificationBtn(QString category)
 void FullFunctionWidget::insertAppList(QStringList desktopfplist)
 {
     FullListView* listview=new FullListView(this,2);
+    //修复异常黑框问题
+    connect(m_scrollArea, &ScrollArea::requestUpdate, listview->viewport(), [=](){
+        listview->repaint(listview->rect());
+    });
+    connect(listview, &FullListView::sendSetslidebar, this, &FullFunctionWidget::onSetSlider);
+    connect(this, &FullFunctionWidget::selectFirstItem, listview, &FullListView::selectFirstItem);
+    listview->installEventFilter(this);
     m_scrollAreaWidLayout->addWidget(listview);
     m_data.clear();
     for(int i=0;i<desktopfplist.count();i++)
@@ -187,109 +203,14 @@ void FullFunctionWidget::insertAppList(QStringList desktopfplist)
     connect(listview,&FullListView::sendHideMainWindowSignal,this,&FullFunctionWidget::sendHideMainWindowSignal);
 }
 
-//void FullFunctionWidget::updateRecentListView()
-//{
-//    data.clear();
-//    QStringList recentlist;
-//    recentlist.clear();
-//    recentlist=pUkuiMenuInterface->getRecentApp();
-//    if(!recentlist.isEmpty())//最近添加非空
-//    {
-//        if(m_classificationList.contains(tr("Recently")))//有最近添加分类
-//        {
-//            QLayoutItem *child;
-//            if((child = m_scrollAreaWidLayout->itemAt(1)) != 0)
-//            {
-//                QWidget* wid=child->widget();
-//                FullListView* listview=qobject_cast<FullListView*>(wid);
-//                for(int i=0;i<recentlist.count();i++)
-//                {
-//                    QString desktopfp=pUkuiMenuInterface->getDesktopPathByAppName(recentlist.at(i));
-//                    data.append(desktopfp);
-//                }
-//                listview->updateData(data);
-//            }
-//        }
-//        else//无最近添加分类
-//        {
-//            PushButton* classificationbtn=new PushButton(this,tr("Recently"),scrollarea->width()-12,20);
-//            classificationbtn->setFixedSize(scrollarea->width()-12,20);
-//            m_scrollAreaWidLayout->insertWidget(0,classificationbtn);
-//            m_classificationList.insert(0,tr("Recently"));
-
-//            FullListView* listview=new FullListView(this,2);
-//            m_scrollAreaWidLayout->insertWidget(1,listview);
-//            for(int i=0;i<recentlist.count();i++)
-//            {
-
-//                QString desktopfp=pUkuiMenuInterface->getDesktopPathByAppName(recentlist.at(i));
-//                data.append(desktopfp);
-//            }
-//            listview->addData(data);
-//            connect(listview,SIGNAL(sendItemClickedSignal(QString)),this,SLOT(execApplication(QString)));
-
-//            //刷新图标列表界面
-//            Q_FOREACH (QAbstractButton* button, m_buttonList){
-//                m_btnGroup->removeButton(button);
-//            }
-//            m_buttonList.clear();
-//            QLayoutItem *child;
-//            while ((child = m_iconListScrollAreaWidLayout->takeAt(0)) != 0) {
-//                QWidget* wid=child->widget();
-//                m_iconListScrollAreaWidLayout->removeWidget(wid);
-//                wid->setParent(nullptr);
-//                delete wid;
-//                delete child;
-//            }
-//            initIconListScrollArea();
-//        }
-//    }
-//    else//最近添加为空
-//    {
-//        if(m_classificationList.contains(tr("Recently")))
-//        {
-//            int num=0;
-//            QLayoutItem *child;
-//             while ((child = m_scrollAreaWidLayout->takeAt(0)) != 0) {
-//                 QWidget* wid=child->widget();
-//                 m_scrollAreaWidLayout->removeWidget(wid);
-//                 wid->setParent(nullptr);
-//                 delete wid;
-//                 delete child;
-//                 num++;
-//                 if(num==2)
-//                     break;
-//             }
-//             m_classificationList.removeAt(0);
-
-//             //刷新图标列表界面
-//             Q_FOREACH (QAbstractButton* button, m_buttonList){
-//                 m_btnGroup->removeButton(button);
-//             }
-//             m_buttonList.clear();
-//             while ((child = m_iconListScrollAreaWidLayout->takeAt(0)) != 0) {
-//                 QWidget* wid=child->widget();
-//                 m_iconListScrollAreaWidLayout->removeWidget(wid);
-//                 wid->setParent(nullptr);
-//                 delete wid;
-//                 delete child;
-//             }
-//             initIconListScrollArea();
-//        }
-//    }
-//    resizeScrollAreaControls();
-//    setting->endGroup();
-//}
-
 /**
  * 执行应用程序
  */
 void FullFunctionWidget::execApplication(QString desktopfp)
 {
     Q_EMIT sendHideMainWindowSignal();
-    GDesktopAppInfo * desktopAppInfo=g_desktop_app_info_new_from_filename(desktopfp.toLocal8Bit().data());
-    g_app_info_launch(G_APP_INFO(desktopAppInfo),nullptr, nullptr, nullptr);
-    g_object_unref(desktopAppInfo);}
+    execApp(desktopfp);
+}
 
 /**
  * 更新应用列表
@@ -298,6 +219,7 @@ void FullFunctionWidget::updateAppListView()
 {
     //刷新应用列表界面
     QLayoutItem *child;
+    m_scrollAreaWidLayout->removeItem(m_appListBottomSpacer);
      while ((child = m_scrollAreaWidLayout->takeAt(0)) != 0) {
          QWidget* wid=child->widget();
          m_scrollAreaWidLayout->removeWidget(wid);
@@ -312,6 +234,8 @@ void FullFunctionWidget::updateAppListView()
         m_btnGroup->removeButton(button);
     }
     m_buttonList.clear();
+    m_iconListScrollAreaWidLayout->removeItem(m_topSpacerItem);
+    m_iconListScrollAreaWidLayout->removeItem(m_bottomSpacerItem);
     while ((child = m_iconListScrollAreaWidLayout->takeAt(0)) != 0) {
         QWidget* wid=child->widget();
         m_iconListScrollAreaWidLayout->removeWidget(wid);
@@ -358,14 +282,21 @@ void FullFunctionWidget::resizeScrollAreaControls()
  */
 void FullFunctionWidget::initIconListWidget()
 {
-    m_iconListScrollArea=new ClassifyScrollArea(m_iconListWid);
-    m_iconListScrollAreaWid=new QWidget;
+    m_iconListScrollArea=new ClassifyBtnScrollArea(m_iconListWid);
+//    m_iconListScrollArea->resize(Style::LeftBtnWidth,
+//                                       m_iconListWid->height());
+    m_iconListScrollAreaWid=new ClassifyBtnScrollAreaWid;
+    m_iconListScrollAreaWid->setFixedSize(Style::LeftBtnWidth,
+                                          m_iconListWid->height());
     m_iconListScrollAreaWidLayout=new QVBoxLayout;
     m_iconListScrollAreaWidLayout->setContentsMargins(0,0,0,0);
     m_iconListScrollAreaWidLayout->setSpacing(Style::LeftSpaceBetweenItem);
     m_iconListScrollAreaWid->setLayout(m_iconListScrollAreaWidLayout);
     m_iconListScrollArea->setWidget(m_iconListScrollAreaWid);
 
+    m_topSpacerItem=new QSpacerItem(20,40,QSizePolicy::Fixed,QSizePolicy::Expanding);
+    m_bottomSpacerItem=new QSpacerItem(20,40,QSizePolicy::Fixed,QSizePolicy::Expanding);
+
     m_btnGroup=new QButtonGroup(m_iconListScrollAreaWid);
     m_animation = new QPropertyAnimation(m_iconListScrollArea, "geometry");
 
@@ -382,34 +313,30 @@ void FullFunctionWidget::initIconListWidget()
  */
 void FullFunctionWidget::initIconListScrollArea()
 {
+    m_iconListScrollAreaWidLayout->addItem(m_topSpacerItem);
     for(int i=0;i<m_classificationList.size();i++)
-//    QVector<QStringList> vector=UkuiMenuInterface::functionalVector;
-//    QStringList androidlist=vector.at(0);
-//    for(int index=0;index<vector.size();index++)
     {
-//        if(!vector.at(index).isEmpty())
-//        {
-            FunctionClassifyButton* iconbtn=new FunctionClassifyButton(
-                                                                       Style::LeftBtnWidth,
-                                                                       Style::LeftBtnHeight,
-                                                                       Style::LeftIconSize,
-                                                                       m_classificationList.at(i),
-                                                                       true,
-                                                                       true);
-            iconbtn->setChecked(false);
-            m_buttonList.append(iconbtn);
-            m_iconListScrollAreaWidLayout->addWidget(iconbtn);
-//        }
-
+        FunctionClassifyButton* iconbtn=new FunctionClassifyButton(
+                    Style::LeftBtnWidth,
+                    Style::LeftBtnHeight,
+                    Style::LeftIconSize,
+                    m_classificationList.at(i),
+                    true,
+                    true);
+        iconbtn->setChecked(false);
+        m_buttonList.append(iconbtn);
+        m_iconListScrollAreaWidLayout->addWidget(iconbtn);
     }
+    m_iconListScrollAreaWidLayout->addItem(m_bottomSpacerItem);
 
     int id=0;
     Q_FOREACH (QAbstractButton* btn, m_buttonList) {
         m_btnGroup->addButton(btn,id++);
     }
     connect(m_btnGroup,static_cast<void(QButtonGroup::*)(QAbstractButton*)>(&QButtonGroup::buttonClicked),this,&FullFunctionWidget::btnGroupClickedSlot);
-    m_iconListScrollArea->widget()->adjustSize();
-    m_btnGroup->button(0)->click();
+//    m_iconListScrollArea->widget()->adjustSize();
+    if(m_btnGroup->button(0)!=nullptr)
+        m_btnGroup->button(0)->click();
 }
 
 void FullFunctionWidget::btnGroupClickedSlot(QAbstractButton *btn)
@@ -487,16 +414,21 @@ void FullFunctionWidget::valueChangedSlot(int value)
     }
 }
 
+QAbstractButton* FullFunctionWidget::getCurLetterButton(int value)
+{
+    return m_buttonList.at(value);
+}
+
+
 void FullFunctionWidget::enterAnimation()
 {
-    int height=m_classificationList.size()*Style::LeftBtnHeight+(m_classificationList.size()-1)*Style::LeftSpaceBetweenItem;
     m_animation->setDuration(200);//动画总时间
-    m_animation->setStartValue(QRect(0,(m_iconListWid->height()-height)/2,
-                                    0,height));
+    m_animation->setStartValue(QRect(0,0,
+                                    0,m_iconListWid->height()));
     m_animation->setEndValue(QRect(Style::LeftMargin,
-                                  (m_iconListWid->height()-height)/2,
+                                  0,
                                   Style::LeftBtnWidth,
-                                  height));
+                                  m_iconListWid->height()));
     m_animation->setEasingCurve(QEasingCurve::InQuart);
     m_animation->start();
     m_iconListScrollArea->show();
@@ -504,11 +436,11 @@ void FullFunctionWidget::enterAnimation()
 
 void FullFunctionWidget::setFunctionBtnGeometry()
 {
-    int height=m_classificationList.size()*Style::LeftBtnHeight+(m_classificationList.size()-1)*Style::LeftSpaceBetweenItem;
+//    int height=m_classificationList.size()*Style::LeftBtnHeight+(m_classificationList.size()-1)*Style::LeftSpaceBetweenItem;
     m_iconListScrollArea->setGeometry(QRect(Style::LeftMargin,
-                                            (m_iconListWid->height()-height)/2,
+                                            0,
                                             Style::LeftBtnWidth,
-                                            height));
+                                            m_iconListWid->height()));
     m_iconListScrollArea->show();
 
 }
@@ -518,32 +450,137 @@ void FullFunctionWidget::repaintWidget()
     this->setFixedSize(Style::MainViewWidWidth,
                        Style::AppListWidHeight);
     m_applistWid->setFixedSize(Style::AppListWidWidth,this->height());
-    m_iconListWid->setFixedSize(Style::LeftWidWidth,this->height());
     m_scrollArea->setFixedSize(m_applistWid->width(),m_applistWid->height());
+    m_iconListWid->setFixedSize(Style::LeftWidWidth,this->height());
+    m_iconListScrollAreaWid->setFixedSize(Style::LeftBtnWidth,
+                                          m_iconListWid->height());
     updateAppListView();
 }
 
 void FullFunctionWidget::widgetMakeZero()
 {
-//    Q_FOREACH (QAbstractButton* button, m_buttonList) {
-//        int num=m_classificationList.indexOf(functionnamelist.at(m_buttonList.indexOf(button)));
-//        if(num!=-1)
-//        {
-//            m_btnGroup->button(num)->setChecked(true);
-//            m_btnGroup->button(num)->click();
-//            m_iconListScrollArea->verticalScrollBar()->setSliderPosition(0);
-//            break;
-//        }
-//    }
-    m_btnGroup->button(0)->click();
+    if(m_btnGroup->button(0)!=nullptr)
+        m_btnGroup->button(0)->click();
     m_scrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
 }
 
 void FullFunctionWidget::moveScrollBar(int type)
 {
-    int height=QApplication::primaryScreen()->geometry().height();
+    int height=Style::primaryScreenHeight;
     if(type==0)
         m_scrollArea->verticalScrollBar()->setSliderPosition(m_scrollArea->verticalScrollBar()->sliderPosition()-height*100/1080);
     else
         m_scrollArea->verticalScrollBar()->setSliderPosition(m_scrollArea->verticalScrollBar()->sliderPosition()+height*100/1080);
 }
+
+void FullFunctionWidget::onSetSlider(int value)
+{
+//    if(flag)
+//    {
+//        flag = false;
+//        time->start(100);
+        int curvalue = m_scrollArea->verticalScrollBar()->value();
+        m_scrollArea->verticalScrollBar()->setValue(curvalue + value);
+//        qDebug() << "FullFunctionWidget::onSetSlider" << curvalue;
+//    }
+}
+
+bool FullFunctionWidget::eventFilter(QObject *watched, QEvent *event)
+{
+    if( event->type() == QEvent::KeyPress )
+    {
+        QLayoutItem* widItem = m_scrollAreaWidLayout->itemAt(2 * m_buttonList.size() - 1);
+        QWidget* wid = widItem->widget();
+        FullListView* m_listview = qobject_cast<FullListView*>(wid);
+
+        QLayoutItem* widItemTop = m_scrollAreaWidLayout->itemAt(1);
+        QWidget* widTop = widItemTop->widget();
+        FullListView* m_listviewTop = qobject_cast<FullListView*>(widTop);
+
+        QKeyEvent *ke = (QKeyEvent *)event;
+        if( ke->key() == Qt::Key_Tab )
+        {
+           Q_EMIT setFocusToSideWin();
+        }
+//        if(ke->key() == Qt::Key_Up)
+//        {
+//            QLayoutItem* widItemTop = m_scrollAreaWidLayout->itemAt(1);
+//            QWidget* widTop = widItemTop->widget();
+//            FullListView* m_listviewTop = qobject_cast<FullListView*>(widTop);
+//            if(!m_listviewTop->hasFocus())
+//            {
+//                QAbstractButton* buttonTop = getCurLetterButton(( --m_index) % m_buttonList.size());
+//                btnGroupClickedSlot(buttonTop);
+//                this->m_scrollArea->setFocusToPreChild();
+//                return true;
+//            }
+//        }
+//        if(ke->key() == Qt::Key_Down)
+//        {
+//            QLayoutItem* widItem = m_scrollAreaWidLayout->itemAt(2 * m_buttonList.size() - 1);
+//            QWidget* wid = widItem->widget();
+//            FullListView* m_listview = qobject_cast<FullListView*>(wid);
+
+//            if(!m_listview->hasFocus())
+//            {
+//                QAbstractButton* button = getCurLetterButton(( ++m_index) % m_buttonList.size());
+//                btnGroupClickedSlot(button);
+//                this->m_scrollArea->setFocusToNextChild();
+//                return true;
+//            }
+//        }
+
+        if(ke->key() == Qt::Key_Up)
+        {
+            if(!m_listviewTop->hasFocus())
+            {
+                QAbstractButton* buttonTop = getCurLetterButton(( --m_index) % m_buttonList.size());
+                btnGroupClickedSlot(buttonTop);
+                this->m_scrollArea->setFocusToPreChild();
+            }
+            else
+            {
+               m_listview->setFocus();
+               QAbstractButton* button = getCurLetterButton(m_buttonList.size() - 1);
+               btnGroupClickedSlot(button);
+               m_index = m_buttonList.size() - 1;
+            }
+            Q_EMIT selectFirstItem();
+            return true;
+        }
+        if(ke->key() == Qt::Key_Down)
+        {
+            if(!m_listview->hasFocus())
+            {
+                QAbstractButton* button = getCurLetterButton(( ++m_index) % m_buttonList.size());
+                btnGroupClickedSlot(button);
+                this->m_scrollArea->setFocusToNextChild();
+            }
+            else
+            {
+                m_listviewTop->setFocus();
+                QAbstractButton* buttonTop = getCurLetterButton(0);
+                btnGroupClickedSlot(buttonTop);
+                m_listviewTop->setCurrentIndex(m_listviewTop->model()->index(0,0));
+                m_index = 0;
+            }
+            Q_EMIT selectFirstItem();
+            return true;
+        }
+    }
+    return QWidget::eventFilter(watched,event);
+}
+
+void FullFunctionWidget::functionButtonClick()
+{
+    if(m_btnGroup->button(0)!=nullptr)
+        m_btnGroup->button(0)->click();
+    m_index = 0;
+}
+
+void FullFunctionWidget::setFocusToThis()
+{
+    functionButtonClick();
+    this->setFocus();
+    Q_EMIT selectFirstItem();
+}
