@@ -38,7 +38,6 @@ void FunctionWidget::initUi()
 {
     this->setWindowFlags(Qt::CustomizeWindowHint | Qt::FramelessWindowHint);
     this->setAttribute(Qt::WA_StyledBackground,true);
-    this->setStyleSheet("border:0px;background:transparent;");
     this->setSizePolicy(QSizePolicy::Fixed,QSizePolicy::Fixed);
     this->setFixedSize(Style::defaultMainViewWidWidth,Style::defaultContentWidHeight);
 
@@ -56,7 +55,6 @@ void FunctionWidget::initUi()
     m_leaveAnimation->setPropertyName(QString("geometry").toLocal8Bit());
     connect(m_leaveAnimation,&QPropertyAnimation::finished,this,&FunctionWidget::animationFinishedSLot);
     connect(m_enterAnimation,&QPropertyAnimation::finished,this,&FunctionWidget::animationFinishedSLot);
-
 }
 
 /**
@@ -64,8 +62,8 @@ void FunctionWidget::initUi()
  */
 void FunctionWidget::initAppListWidget()
 {
-    m_appListView=new ListView(this,this->width()-4,this->height(),2);
-    m_appListView->setGeometry(QRect(0,0,this->width()-4,this->height()));
+    m_appListView=new ListView(this,this->width()-6,this->height()-6,2);
+    m_appListView->setGeometry(QRect(6,0,this->width()-6,this->height()-6));
     m_appListView->show();
     fillAppListView(0);
     connect(m_appListView,&ListView::sendItemClickedSignal,this,&FunctionWidget::recvItemClickedSlot);
@@ -185,9 +183,7 @@ void FunctionWidget::recvItemClickedSlot(QStringList arg)
 void FunctionWidget::execApplication(QString desktopfp)
 {
     Q_EMIT sendHideMainWindowSignal();
-    GDesktopAppInfo * desktopAppInfo=g_desktop_app_info_new_from_filename(desktopfp.toLocal8Bit().data());
-    g_app_info_launch(G_APP_INFO(desktopAppInfo),nullptr, nullptr, nullptr);
-    g_object_unref(desktopAppInfo);
+    execApp(desktopfp);
 }
 
 /**
@@ -203,15 +199,16 @@ void FunctionWidget::updateAppListView()
  */
 void FunctionWidget::appClassificationBtnClickedSlot()
 {
-    m_leaveAnimation->setStartValue(QRect(0,0,this->width()-4,this->height()));
-    m_leaveAnimation->setEndValue(QRect(20,20,this->width()-40,this->height()-40));
+    m_leaveAnimation->setStartValue(QRect(6,0,this->width()-6,this->height()-6));
+//    m_leaveAnimation->setEndValue(QRect(20,20,this->width()-40,this->height()-40));
+    m_leaveAnimation->setEndValue(QRect(6,0,this->width()-6,this->height()-6));
     m_enterAnimation->setStartValue(QRect(-40,-40,this->width()+80,this->height()+80));
     m_enterAnimation->setEndValue(QRect((this->width()-Style::LeftBtnWidth*2-5)/2,
                                       (this->height()-Style::LeftBtnHeight*6-25)/2,
                                       Style::LeftBtnWidth*2+5,
                                       Style::LeftBtnHeight*6+25));
     m_leaveAnimation->setDuration(10);
-    m_enterAnimation->setDuration(80);
+    m_enterAnimation->setDuration(100);
 
     //加载FunctionButtonWidget界面
     Q_EMIT sendClassificationbtnList();
@@ -239,9 +236,10 @@ void FunctionWidget::recvFunctionBtnSignal(QString btnname)
                                         Style::LeftBtnWidth*2+5,
                                         Style::LeftBtnHeight*6+25));
     m_leaveAnimation->setEndValue(QRect(-40,-40,this->width()+80,this->height()+80));
-    m_enterAnimation->setStartValue(QRect(20,20,this->width()-40,this->height()-40));
-    m_enterAnimation->setEndValue(QRect(0,0,this->width()-4,this->height()));
-    m_leaveAnimation->setDuration(80);
+//    m_enterAnimation->setStartValue(QRect(20,20,this->width()-40,this->height()-40));
+    m_enterAnimation->setStartValue(QRect(6,0,this->width()-6,this->height()-6));
+    m_enterAnimation->setEndValue(QRect(6,0,this->width()-6,this->height()-6));
+    m_leaveAnimation->setDuration(100);
     m_enterAnimation->setDuration(10);
 
     m_leaveAnimation->setTargetObject(m_functionBtnWid);
@@ -271,7 +269,7 @@ void FunctionWidget::animationFinishedSLot()
 void FunctionWidget::widgetMakeZero()
 {
     m_functionBtnWid->hide();
-    m_appListView->setGeometry(QRect(0,0,this->width()-4,this->height()));
+    m_appListView->setGeometry(QRect(6,0,this->width()-6,this->height()-6));
     m_appListView->show();
     m_appListView->verticalScrollBar()->setValue(0);
 }
@@ -287,6 +285,11 @@ void FunctionWidget::moveScrollBar(int type)
 void FunctionWidget::repaintWidget()
 {
     this->setFixedSize(Style::defaultMainViewWidWidth,Style::defaultContentWidHeight);
-    m_appListView->setGeometry(QRect(0,0,this->width()-4,this->height()));
+    m_appListView->setGeometry(QRect(6,0,this->width()-6,this->height()-6));
     m_appListView->show();
 }
+
+void FunctionWidget::setFocusToThis()
+{
+    this->setFocus();
+}
