@@ -17,18 +17,19 @@
  */
 
 #include "ukuimenuinterface.h"
-#include <glib.h>
 #include <QDir>
 #include <QDebug>
 #include <QCollator>
 #include <QLocale>
 #include <QStringList>
+#include <QJsonArray>
+#include <QJsonObject>
+#include <unistd.h>
 #include "ukuichineseletter.h"
+#include "src/UtilityFunction/utility.h"
 
 UkuiMenuInterface::UkuiMenuInterface()
 {
-    QString path=QDir::homePath()+"/.config/ukui/ukui-menu.ini";
-    setting=new QSettings(path,QSettings::IniFormat);
 }
 
 QVector<QStringList> UkuiMenuInterface::appInfoVector=QVector<QStringList>();
@@ -75,11 +76,30 @@ void UkuiMenuInterface::recursiveSearchFile(const QString& _filePath)
                 i++;
                 continue;
             }
-            keyfile=g_key_file_new();
 
             QByteArray fpbyte=filePathStr.toLocal8Bit();
             char* filepath=fpbyte.data();
-            g_key_file_load_from_file(keyfile,filepath,flags,error);
+            if(0!=access(filepath,R_OK))//判断文件是否可读
+            {
+                i++;
+                continue;
+            }
+
+            keyfile=g_key_file_new();
+            if(!g_key_file_load_from_file(keyfile,filepath,flags,error))
+                return;
+
+            char* ret_0 = g_key_file_get_locale_string(keyfile,"Desktop Entry","Categories", nullptr, nullptr);
+            if(ret_0 != nullptr)
+            {
+                QString str = QString::fromLocal8Bit(ret_0);
+                if(str.contains("Android"))
+                {
+                    g_key_file_free(keyfile);
+                    i++;
+                    continue;
+                }
+            }
             char* ret_1=g_key_file_get_locale_string(keyfile,"Desktop Entry","NoDisplay", nullptr, nullptr);
             if(ret_1!=nullptr)
             {
@@ -115,29 +135,6 @@ void UkuiMenuInterface::recursiveSearchFile(const QString& _filePath)
                     continue;
                 }
             }
-            //过滤中英文名为空的情况
-            QLocale cn;
-            QString language=cn.languageToString(cn.language());
-            if(QString::compare(language,"Chinese")==0)
-            {
-                char* nameCh=g_key_file_get_string(keyfile,"Desktop Entry","Name[zh_CN]", nullptr);
-                char* nameEn=g_key_file_get_string(keyfile,"Desktop Entry","Name", nullptr);
-                if(QString::fromLocal8Bit(nameCh).isEmpty() && QString::fromLocal8Bit(nameEn).isEmpty())
-                {
-                    g_key_file_free(keyfile);
-                    i++;
-                    continue;
-                }
-            }
-            else {
-                char* name=g_key_file_get_string(keyfile,"Desktop Entry","Name", nullptr);
-                if(QString::fromLocal8Bit(name).isEmpty())
-                {
-                    g_key_file_free(keyfile);
-                    i++;
-                    continue;
-                }
-            }
 
             g_key_file_free(keyfile);
             filePathList.append(filePathStr);
@@ -151,13 +148,71 @@ void UkuiMenuInterface::recursiveSearchFile(const QString& _filePath)
 QStringList UkuiMenuInterface::getDesktopFilePath()
 {
     filePathList.clear();
-    getAndroidApp();
-    recursiveSearchFile("/usr/share/applications/");
+
+    QString jsonPath=QDir::homePath()+"/.config/ukui-menu-security-config.json";
+    QFile file(jsonPath);
+    if(file.exists())
+    {
+        file.open(QIODevice::ReadOnly);
+        QByteArray readBy=file.readAll();
+        QJsonParseError error;
+        QJsonDocument readDoc=QJsonDocument::fromJson(readBy,&error);
+        if(!readDoc.isNull() && error.error==QJsonParseError::NoError)
+        {
+            QJsonObject obj=readDoc.object().value("ukui-menu").toObject();
+            if(obj.value("mode").toString()=="whitelist")
+            {
+                QJsonArray blArray=obj.value("whitelist").toArray();
+                QJsonArray enArray=blArray.at(0).toObject().value("entries").toArray();
+                for(int index=0;index<enArray.size();index++)
+                {
+                    QJsonObject obj=enArray.at(index).toObject();
+                    filePathList.append(obj.value("path").toString());
+//                    qDebug()<<obj.value("path").toString();
+                }
+                return filePathList;
+            }
+            else if(obj.value("mode").toString()=="blacklist")
+            {
+                getAndroidApp();
+                recursiveSearchFile("/usr/share/applications/");
+                recursiveSearchFile(QDir::homePath()+"/.local/share/applications/");
+                recursiveSearchFile("/var/lib/snapd/desktop/applications/");
+                recursiveSearchFile("/var/lib/flatpak/exports/share/applications/");
+                QJsonArray blArray=obj.value("blacklist").toArray();
+                QJsonArray enArray=blArray.at(0).toObject().value("entries").toArray();
+                for(int index=0;index<enArray.size();index++)
+                {
+                    QJsonObject obj=enArray.at(index).toObject();
+                    filePathList.removeAll(obj.value("path").toString());
+//                    qDebug()<<obj.value("path").toString();
+                }
+            }
+            else
+            {
+                getAndroidApp();
+                recursiveSearchFile("/usr/share/applications/");
+                recursiveSearchFile(QDir::homePath()+"/.local/share/applications/");
+                recursiveSearchFile("/var/lib/snapd/desktop/applications/");
+                recursiveSearchFile("/var/lib/flatpak/exports/share/applications/");
+            }
+
+        }
+
+        file.close();
+    }
+    else
+    {
+        getAndroidApp();
+        recursiveSearchFile("/usr/share/applications/");
+        recursiveSearchFile(QDir::homePath()+"/.local/share/applications/");
+        recursiveSearchFile("/var/lib/snapd/desktop/applications/");
+        recursiveSearchFile("/var/lib/flatpak/exports/share/applications/");
+    }
 
     filePathList.removeAll("/usr/share/applications/software-properties-livepatch.desktop");
     filePathList.removeAll("/usr/share/applications/mate-color-select.desktop");
     filePathList.removeAll("/usr/share/applications/blueman-adapters.desktop");
-    filePathList.removeAll("/usr/share/applications/blueman-manager.desktop");
     filePathList.removeAll("/usr/share/applications/mate-user-guide.desktop");
     filePathList.removeAll("/usr/share/applications/nm-connection-editor.desktop");
     filePathList.removeAll("/usr/share/applications/debian-uxterm.desktop");
@@ -181,10 +236,6 @@ QStringList UkuiMenuInterface::getDesktopFilePath()
     filePathList.removeAll("/usr/share/applications/system-config-printer.desktop");
     filePathList.removeAll("/usr/share/applications/org.gnome.DejaDup.desktop");
     filePathList.removeAll("/usr/share/applications/yelp.desktop");
-    filePathList.removeAll("/usr/share/applications/peony-computer.desktop");
-    filePathList.removeAll("/usr/share/applications/peony-home.desktop");
-    filePathList.removeAll("/usr/share/applications/peony-trash.desktop");
-    filePathList.removeAll("/usr/share/applications/peony.desktop");
 
     //v10
     filePathList.removeAll("/usr/share/applications/mate-about.desktop");
@@ -226,26 +277,29 @@ QVector<QStringList> UkuiMenuInterface::createAppInfoVector()
         QStringList appInfoList;
         QString desktopfp=desktopfpList.at(i);
         QString name=getAppName(desktopfpList.at(i));
-        QString englishName=getAppEnglishName(desktopfpList.at(i));
-        QString letter=getAppNameInitial(desktopfpList.at(i));
-        QString letters=getAppNameInitials(desktopfpList.at(i));
-
-        desktopfpVector.append(desktopfp);
-
-        appInfoList<<desktopfp<<name<<englishName<<letter<<letters;
-        bool is_owned=false;
-        for(int j=0;j<vector.size();j++)
+        if(!name.isEmpty())
         {
-            if(matchingAppCategories(desktopfpList.at(i),vector.at(j)))//有对应分类
-            {
-                is_owned=true;
-                appInfoList.append(QString::number(j));
-            }
-        }
-        if(!is_owned)//该应用无对应分类
-            appInfoList.append(QString::number(10));
+            QString englishName=getAppEnglishName(desktopfpList.at(i));
+            QString letter=getAppNameInitial(desktopfpList.at(i));
+            QString letters=getAppNameInitials(desktopfpList.at(i));
 
-        appInfoVector.append(appInfoList);
+            desktopfpVector.append(desktopfp);
+
+            appInfoList<<desktopfp<<name<<englishName<<letter<<letters;
+            bool is_owned=false;
+            for(int j=0;j<vector.size();j++)
+            {
+                if(matchingAppCategories(desktopfpList.at(i),vector.at(j)))//有对应分类
+                {
+                    is_owned=true;
+                    appInfoList.append(QString::number(j));
+                }
+            }
+            if(!is_owned)//该应用无对应分类
+                appInfoList.append(QString::number(10));
+
+            appInfoVector.append(appInfoList);
+        }
     }
 
     return appInfoVector;
@@ -375,7 +429,7 @@ bool UkuiMenuInterface::cmpApp(QStringList &arg_1, QStringList &arg_2)
         return false;
 }
 
-QVector<QString> UkuiMenuInterface::getAllApp()
+QVector<QString> UkuiMenuInterface::getAllClassification()
 {
     QVector<QString> allAppVector;
     QVector<QString> commonVector;
@@ -403,69 +457,95 @@ QVector<QString> UkuiMenuInterface::getAllApp()
 
 QVector<QString> UkuiMenuInterface::getCommonUseApp()
 {
-    QDateTime dt=QDateTime::currentDateTime();
-    int currentDateTime=dt.toTime_t();
-    int nDaySec=24*60*60;
-    setting->beginGroup("datetime");
-    QStringList dateTimeKeys=setting->allKeys();
-    QStringList timeOutKeys;
-    timeOutKeys.clear();
-    for(int i=0;i<dateTimeKeys.count();i++)
-    {
-        if((currentDateTime-setting->value(dateTimeKeys.at(i)).toInt())/nDaySec >= 4)
-        {
-            timeOutKeys.append(dateTimeKeys.at(i));
-        }
+//    QDateTime dt=QDateTime::currentDateTime();
+//    int currentDateTime=dt.toTime_t();
+//    int nDaySec=24*60*60;
+//    setting->beginGroup("datetime");
+//    QStringList dateTimeKeys=setting->allKeys();
+//    QStringList timeOutKeys;
+//    timeOutKeys.clear();
+//    for(int i=0;i<dateTimeKeys.count();i++)
+//    {
+//        if((currentDateTime-setting->value(dateTimeKeys.at(i)).toInt())/nDaySec >= 4)
+//        {
+//            timeOutKeys.append(dateTimeKeys.at(i));
+//        }
 
-    }
-    setting->endGroup();
-    for(int i=0;i<timeOutKeys.count();i++)
-    {
-        setting->beginGroup("application");
-        setting->remove(timeOutKeys.at(i));
-        setting->sync();
-        setting->endGroup();
-        setting->beginGroup("datetime");
-        setting->remove(timeOutKeys.at(i));
-        setting->sync();
-        setting->endGroup();
-    }
+//    }
+//    setting->endGroup();
+//    for(int i=0;i<timeOutKeys.count();i++)
+//    {
+//        setting->beginGroup("application");
+//        setting->remove(timeOutKeys.at(i));
+//        setting->sync();
+//        setting->endGroup();
+//        setting->beginGroup("datetime");
+//        setting->remove(timeOutKeys.at(i));
+//        setting->sync();
+//        setting->endGroup();
+//    }
 
-    setting->beginGroup("lockapplication");
-    QStringList lockdesktopfnList=setting->allKeys();
-    for(int i=0;i<lockdesktopfnList.count()-1;i++)
-        for(int j=0;j<lockdesktopfnList.count()-1-i;j++)
-        {
-            int value_1=setting->value(lockdesktopfnList.at(j)).toInt();
-            int value_2=setting->value(lockdesktopfnList.at(j+1)).toInt();
-            if(value_1 > value_2)
-            {
-                QString tmp=lockdesktopfnList.at(j);
-                lockdesktopfnList.replace(j,lockdesktopfnList.at(j+1));
-                lockdesktopfnList.replace(j+1,tmp);
+//    setting->beginGroup("lockapplication");
+//    QStringList lockdesktopfnList=setting->allKeys();
+//    for(int i=0;i<lockdesktopfnList.count()-1;i++)
+//        for(int j=0;j<lockdesktopfnList.count()-1-i;j++)
+//        {
+//            int value_1=setting->value(lockdesktopfnList.at(j)).toInt();
+//            int value_2=setting->value(lockdesktopfnList.at(j+1)).toInt();
+//            if(value_1 > value_2)
+//            {
+//                QString tmp=lockdesktopfnList.at(j);
+//                lockdesktopfnList.replace(j,lockdesktopfnList.at(j+1));
+//                lockdesktopfnList.replace(j+1,tmp);
 
-            }
-        }
-    setting->endGroup();
-    setting->beginGroup("application");
-    QStringList desktopfnList=setting->allKeys();
-    for(int i=0;i<desktopfnList.count()-1;i++)
-        for(int j=0;j<desktopfnList.count()-1-i;j++)
-        {
-            int value_1=setting->value(desktopfnList.at(j)).toInt();
-            int value_2=setting->value(desktopfnList.at(j+1)).toInt();
-            if(value_1 < value_2)
-            {
-                QString tmp=desktopfnList.at(j);
-                desktopfnList.replace(j,desktopfnList.at(j+1));
-                desktopfnList.replace(j+1,tmp);
+//            }
+//        }
+//    setting->endGroup();
+//    setting->beginGroup("application");
+//    QStringList desktopfnList=setting->allKeys();
+//    for(int i=0;i<desktopfnList.count()-1;i++)
+//        for(int j=0;j<desktopfnList.count()-1-i;j++)
+//        {
+//            int value_1=setting->value(desktopfnList.at(j)).toInt();
+//            int value_2=setting->value(desktopfnList.at(j+1)).toInt();
+//            if(value_1 < value_2)
+//            {
+//                QString tmp=desktopfnList.at(j);
+//                desktopfnList.replace(j,desktopfnList.at(j+1));
+//                desktopfnList.replace(j+1,tmp);
 
-            }
-        }
-    setting->endGroup();
+//            }
+//        }
+//    setting->endGroup();
+
+//    QVector<QString> data;
+//    Q_FOREACH(QString desktopfn,lockdesktopfnList)
+//    {
+//        QString desktopfp;
+//        if(androidDesktopfnList.contains(desktopfn))
+//            desktopfp=QString(QDir::homePath()+"/.local/share/applications/"+desktopfn);
+//        else
+//            desktopfp=QString("/usr/share/applications/"+desktopfn);
+//        QFileInfo fileInfo(desktopfp);
+//        if(!fileInfo.isFile()|| !desktopfpVector.contains(desktopfp))
+//            continue;
+//        data.append(desktopfp);
+//    }
+//    Q_FOREACH(QString desktopfn,desktopfnList)
+//    {
+//        QString desktopfp;
+//        if(androidDesktopfnList.contains(desktopfn))
+//            desktopfp=QString(QDir::homePath()+"/.local/share/applications/"+desktopfn);
+//        else
+//            desktopfp=QString("/usr/share/applications/"+desktopfn);
+//        QFileInfo fileInfo(desktopfp);
+//        if(!fileInfo.isFile() || !desktopfpVector.contains(desktopfp))
+//            continue;
+//        data.append(desktopfp);
+//    }
 
     QVector<QString> data;
-    Q_FOREACH(QString desktopfn,lockdesktopfnList)
+    Q_FOREACH(QString desktopfn, getLockAppList())
     {
         QString desktopfp;
         if(androidDesktopfnList.contains(desktopfn))
@@ -473,11 +553,12 @@ QVector<QString> UkuiMenuInterface::getCommonUseApp()
         else
             desktopfp=QString("/usr/share/applications/"+desktopfn);
         QFileInfo fileInfo(desktopfp);
-        if(!fileInfo.isFile())
+        if(!fileInfo.isFile() || !desktopfpVector.contains(desktopfp))
             continue;
         data.append(desktopfp);
     }
-    Q_FOREACH(QString desktopfn,desktopfnList)
+
+    Q_FOREACH(QString desktopfn, getUnlockAllList())
     {
         QString desktopfp;
         if(androidDesktopfnList.contains(desktopfn))
@@ -504,91 +585,93 @@ QVector<QStringList> UkuiMenuInterface::getAlphabeticClassification()
     {
         QString appname=appInfoVector.at(index).at(1);
         QString appnamepy=UkuiChineseLetter::getPinyins(appname);
-        char c=appnamepy.at(0).toLatin1();
-        switch (c) {
-        case 'A':
-            appVector[0].append(appInfoVector.at(index));
-            break;
-        case 'B':
-            appVector[1].append(appInfoVector.at(index));
-            break;
-        case 'C':
-            appVector[2].append(appInfoVector.at(index));
-            break;
-        case 'D':
-            appVector[3].append(appInfoVector.at(index));
-            break;
-        case 'E':
-            appVector[4].append(appInfoVector.at(index));
-            break;
-        case 'F':
-            appVector[5].append(appInfoVector.at(index));
-            break;
-        case 'G':
-            appVector[6].append(appInfoVector.at(index));
-            break;
-        case 'H':
-            appVector[7].append(appInfoVector.at(index));
-            break;
-        case 'I':
-            appVector[8].append(appInfoVector.at(index));
-            break;
-        case 'J':
-            appVector[9].append(appInfoVector.at(index));
-            break;
-        case 'K':
-            appVector[10].append(appInfoVector.at(index));
-            break;
-        case 'L':
-            appVector[11].append(appInfoVector.at(index));
-            break;
-        case 'M':
-            appVector[12].append(appInfoVector.at(index));
-            break;
-        case 'N':
-            appVector[13].append(appInfoVector.at(index));
-            break;
-        case 'O':
-            appVector[14].append(appInfoVector.at(index));
-            break;
-        case 'P':
-            appVector[15].append(appInfoVector.at(index));
-            break;
-        case 'Q':
-            appVector[16].append(appInfoVector.at(index));
-            break;
-        case 'R':
-            appVector[17].append(appInfoVector.at(index));
-            break;
-        case 'S':
-            appVector[18].append(appInfoVector.at(index));
-            break;
-        case 'T':
-            appVector[19].append(appInfoVector.at(index));
-            break;
-        case 'U':
-            appVector[20].append(appInfoVector.at(index));
-            break;
-        case 'V':
-            appVector[21].append(appInfoVector.at(index));
-            break;
-        case 'W':
-            appVector[22].append(appInfoVector.at(index));
-            break;
-        case 'X':
-            appVector[23].append(appInfoVector.at(index));
-            break;
-        case 'Y':
-            appVector[24].append(appInfoVector.at(index));
-            break;
-        case 'Z':
-            appVector[25].append(appInfoVector.at(index));
-            break;
-        default:
-            appVector[26].append(appInfoVector.at(index));
-            break;
+        if(!appnamepy.isEmpty())
+        {
+            char c=appnamepy.at(0).toLatin1();
+            switch (c) {
+            case 'A':
+                appVector[0].append(appInfoVector.at(index));
+                break;
+            case 'B':
+                appVector[1].append(appInfoVector.at(index));
+                break;
+            case 'C':
+                appVector[2].append(appInfoVector.at(index));
+                break;
+            case 'D':
+                appVector[3].append(appInfoVector.at(index));
+                break;
+            case 'E':
+                appVector[4].append(appInfoVector.at(index));
+                break;
+            case 'F':
+                appVector[5].append(appInfoVector.at(index));
+                break;
+            case 'G':
+                appVector[6].append(appInfoVector.at(index));
+                break;
+            case 'H':
+                appVector[7].append(appInfoVector.at(index));
+                break;
+            case 'I':
+                appVector[8].append(appInfoVector.at(index));
+                break;
+            case 'J':
+                appVector[9].append(appInfoVector.at(index));
+                break;
+            case 'K':
+                appVector[10].append(appInfoVector.at(index));
+                break;
+            case 'L':
+                appVector[11].append(appInfoVector.at(index));
+                break;
+            case 'M':
+                appVector[12].append(appInfoVector.at(index));
+                break;
+            case 'N':
+                appVector[13].append(appInfoVector.at(index));
+                break;
+            case 'O':
+                appVector[14].append(appInfoVector.at(index));
+                break;
+            case 'P':
+                appVector[15].append(appInfoVector.at(index));
+                break;
+            case 'Q':
+                appVector[16].append(appInfoVector.at(index));
+                break;
+            case 'R':
+                appVector[17].append(appInfoVector.at(index));
+                break;
+            case 'S':
+                appVector[18].append(appInfoVector.at(index));
+                break;
+            case 'T':
+                appVector[19].append(appInfoVector.at(index));
+                break;
+            case 'U':
+                appVector[20].append(appInfoVector.at(index));
+                break;
+            case 'V':
+                appVector[21].append(appInfoVector.at(index));
+                break;
+            case 'W':
+                appVector[22].append(appInfoVector.at(index));
+                break;
+            case 'X':
+                appVector[23].append(appInfoVector.at(index));
+                break;
+            case 'Y':
+                appVector[24].append(appInfoVector.at(index));
+                break;
+            case 'Z':
+                appVector[25].append(appInfoVector.at(index));
+                break;
+            default:
+                appVector[26].append(appInfoVector.at(index));
+                break;
+            }
         }
-
         index++;
     }
 
@@ -802,6 +885,25 @@ QString UkuiMenuInterface::getAppNamePinyin(QString appname)
     return UkuiChineseLetter::getPinyins(appname);
 }
 
+bool UkuiMenuInterface::checkKreApp(QString desktopfp)
+{
+    GError** error=nullptr;
+    GKeyFileFlags flags=G_KEY_FILE_NONE;
+    GKeyFile* keyfile=g_key_file_new ();
+
+    QByteArray fpbyte=desktopfp.toLocal8Bit();
+    char* filepath=fpbyte.data();
+    g_key_file_load_from_file(keyfile,filepath,flags,error);
+
+    char* value=g_key_file_get_locale_string(keyfile,"Desktop Entry","environment", nullptr, nullptr);
+    g_key_file_free(keyfile);
+    if(!value)
+        return false;
+    else if(QString::compare(QString::fromLocal8Bit(value),"kre-environment")==0)
+        return true;
+    return false;
+}
+
 //获取指定类型应用列表
 QStringList UkuiMenuInterface::getSpecifiedCategoryAppList(QString categorystr)
 {
@@ -835,39 +937,3 @@ QStringList UkuiMenuInterface::getSpecifiedCategoryAppList(QString categorystr)
     return appnameList;
 
 }
-
-//获取用户图像
-QString UkuiMenuInterface::getUserIcon()
-{
-    qint64 uid=static_cast<qint64>(getuid());
-    QDBusInterface iface("org.freedesktop.Accounts",
-                         "/org/freedesktop/Accounts",
-                         "org.freedesktop.Accounts",
-                         QDBusConnection::systemBus());
-    QDBusReply<QDBusObjectPath>objPath=iface.call("FindUserById",uid);
-
-    QDBusInterface useriface("org.freedesktop.Accounts",
-                             objPath.value().path(),
-                             "org.freedesktop.DBus.Properties",
-                             QDBusConnection::systemBus());
-    QDBusReply<QVariant> var=useriface.call("Get","org.freedesktop.Accounts.User","IconFile");
-    QString iconstr=var.value().toString();
-    return iconstr;
-}
-
-QString UkuiMenuInterface::getUserName()
-{
-    qint64 uid=static_cast<qint64>(getuid());
-    QDBusInterface iface("org.freedesktop.Accounts",
-                         "/org/freedesktop/Accounts",
-                         "org.freedesktop.Accounts",
-                         QDBusConnection::systemBus());
-    QDBusReply<QDBusObjectPath> objPath=iface.call("FindUserById",uid);
-    QDBusInterface useriface("org.freedesktop.Accounts",
-                             objPath.value().path(),
-                             "org.freedesktop.DBus.Properties",
-                             QDBusConnection::systemBus());
-    QDBusReply<QVariant> var=useriface.call("Get","org.freedesktop.Accounts.User","UserName");
-    QString name=var.value().toString();
-    return name;
-}
