@@ -29,6 +29,8 @@ FullLetterWidget::FullLetterWidget(QWidget *parent) :
 FullLetterWidget::~FullLetterWidget()
 {
     delete m_ukuiMenuInterface;
+    delete m_letterListBottomSpacer;
+    delete m_appListBottomSpacer;
 }
 
 /**
@@ -37,9 +39,8 @@ FullLetterWidget::~FullLetterWidget()
 void FullLetterWidget::initUi()
 {
     this->setWindowFlags(Qt::CustomizeWindowHint | Qt::FramelessWindowHint);
-    this->setAttribute(Qt::WA_StyledBackground,true);
-    this->setStyleSheet("border:0px;background:transparent;");
     this->setSizePolicy(QSizePolicy::Fixed,QSizePolicy::Fixed);
+    this->setAttribute(Qt::WA_TranslucentBackground);
 
     m_applistWid=new QWidget(this);
     m_letterListWid=new QWidget(this);
@@ -51,8 +52,6 @@ void FullLetterWidget::initUi()
     QHBoxLayout* mainLayout=new QHBoxLayout;
     mainLayout->setContentsMargins(0,0,0,0);
     mainLayout->setSpacing(0);
-    m_applistWid->setStyleSheet("border:0px;background: transparent;");
-    m_letterListWid->setStyleSheet("border:0px;background: transparent;");
     mainLayout->addWidget(m_letterListWid);
     mainLayout->addWidget(m_applistWid);
     this->setLayout(mainLayout);
@@ -60,6 +59,17 @@ void FullLetterWidget::initUi()
 
     initAppListWidget();
     initLetterListWidget();
+
+    flag = true;
+    //翻页灵敏度时间调节
+    time = new QTimer(this);
+    connect(time,&QTimer::timeout,[=](){
+        if(flag == false)
+        {
+            flag = true;
+            time->stop();
+        }
+    });
 }
 
 /**
@@ -72,7 +82,7 @@ void FullLetterWidget::initAppListWidget()
     m_applistWid->setLayout(layout);
 
     m_scrollArea=new ScrollArea;
-    m_scrollAreaWid=new QWidget;
+    m_scrollAreaWid=new ScrollAreaWid;
     m_scrollArea->setWidget(m_scrollAreaWid);
     m_scrollArea->setFixedSize(m_applistWid->width(),m_applistWid->height());
     m_scrollArea->setWidgetResizable(true);
@@ -83,9 +93,16 @@ void FullLetterWidget::initAppListWidget()
     layout->addWidget(m_scrollArea);
     connect(m_scrollArea->verticalScrollBar(),&QScrollBar::valueChanged,
             this,&FullLetterWidget::valueChangedSlot);
+    m_appListBottomSpacer=new QSpacerItem(20,40,QSizePolicy::Fixed,QSizePolicy::Expanding);
 
     fillAppList();
+}
 
+void FullLetterWidget::setFocusToThis()
+{
+    letterButtonClick();
+    this->setFocus();
+    Q_EMIT selectFirstItem();
 }
 
 /**
@@ -109,12 +126,19 @@ void FullLetterWidget::fillAppList()
                 letterstr="#";
             m_letterList.append(letterstr);//存储分类字符
             //插入字母分类按钮
-            PushButton* letterbtn=new PushButton(this,letterstr,m_scrollArea->width()-12,30,1);
-//            letterbtn->setFixedSize(m_scrollArea->width(),20);
+            SplitBarFrame* letterbtn=new SplitBarFrame(this,letterstr,m_scrollArea->width()-12,30,1);
             m_scrollAreaWidLayout->addWidget(letterbtn);
 
             //插入应用列表
             FullListView* listview=new FullListView(this,1);
+            connect(listview, &FullListView::sendSetslidebar,this,&FullLetterWidget::onSetSlider);
+            connect(this, &FullLetterWidget::selectFirstItem, listview, &FullListView::selectFirstItem);
+            listview->installEventFilter(this);
+            //修复异常黑框问题
+            connect(m_scrollArea, &ScrollArea::requestUpdate, listview->viewport(), [=](){
+                listview->repaint(listview->rect());
+            });
+
             m_scrollAreaWidLayout->addWidget(listview);
             m_data.clear();
             for(int i=0;i<appList.count();i++)
@@ -126,8 +150,9 @@ void FullLetterWidget::fillAppList()
             connect(listview,&FullListView::sendHideMainWindowSignal,this,&FullLetterWidget::sendHideMainWindowSignal);
         }
     }
+    m_scrollAreaWidLayout->addItem(m_appListBottomSpacer);
 
-        resizeScrollAreaControls();
+    resizeScrollAreaControls();
 }
 
 /**
@@ -136,9 +161,7 @@ void FullLetterWidget::fillAppList()
 void FullLetterWidget::execApplication(QString desktopfp)
 {
     Q_EMIT sendHideMainWindowSignal();
-    GDesktopAppInfo * desktopAppInfo=g_desktop_app_info_new_from_filename(desktopfp.toLocal8Bit().data());
-    g_app_info_launch(G_APP_INFO(desktopAppInfo),nullptr, nullptr, nullptr);
-    g_object_unref(desktopAppInfo);
+    execApp(desktopfp);
 }
 
 /**
@@ -148,6 +171,7 @@ void FullLetterWidget::updateAppListView()
 {
     //刷新应用列表界面
     QLayoutItem *child;
+    m_scrollAreaWidLayout->removeItem(m_appListBottomSpacer);
      while ((child = m_scrollAreaWidLayout->takeAt(0)) != 0) {
          QWidget* wid=child->widget();
          m_scrollAreaWidLayout->removeWidget(wid);
@@ -212,8 +236,8 @@ void FullLetterWidget::resizeScrollAreaControls()
  */
 void FullLetterWidget::initLetterListWidget()
 {
-    m_letterListScrollArea=new ClassifyScrollArea(m_letterListWid);
-    m_letterListScrollAreaWid=new QWidget(m_letterListScrollArea);
+    m_letterListScrollArea=new ClassifyBtnScrollArea(m_letterListWid);
+    m_letterListScrollAreaWid=new ClassifyBtnScrollAreaWid;
     m_letterListScrollAreaWidLayout=new QVBoxLayout;
     m_letterListScrollAreaWidLayout->setContentsMargins(0,0,0,0);
     m_letterListScrollAreaWidLayout->setSpacing(0);
@@ -238,19 +262,14 @@ void FullLetterWidget::initLetterListWidget()
  */
 void FullLetterWidget::initLetterListScrollArea()
 {
-//    m_letterListScrollArea->setStyleSheet("border:1px solid #ff0000;");
-//    m_letterListScrollArea->setFixedSize(Style::LeftLetterBtnHeight*2,
-//                                       (m_letterList.size()+1)*Style::LeftLetterBtnHeight);
-
-//    m_letterListScrollArea->setStyleSheet("border:1px solid #ff0000;");
     if(m_letterList.contains("&"))
         m_letterList.replace(m_letterList.indexOf("&"),"&&");
     for(int i=0;i<m_letterList.size();i++)
     {
         LetterClassifyButton* letterbtn=new LetterClassifyButton(m_letterListScrollAreaWid,
-                                                                 ClassifyBtnHoverBackground,
-                                                                 ClassifyBtnHoverBackground,
+                                                                 true,
                                                                  m_letterList.at(i));
+        letterbtn->setFixedSize(Style::LeftLetterBtnHeight,Style::LeftLetterBtnHeight);
         m_buttonList.append(letterbtn);
         m_letterListScrollAreaWidLayout->addWidget(letterbtn);
         m_letterListScrollAreaWidLayout->setAlignment(letterbtn,Qt::AlignHCenter);
@@ -265,7 +284,8 @@ void FullLetterWidget::initLetterListScrollArea()
 
     connect(m_btnGroup,static_cast<void(QButtonGroup::*)(QAbstractButton*)>(&QButtonGroup::buttonClicked),this,&FullLetterWidget::btnGroupClickedSlot);
     m_letterListScrollArea->widget()->adjustSize();
-    m_btnGroup->button(0)->click();
+    if(m_btnGroup->button(0)!=nullptr)
+        m_btnGroup->button(0)->click();
 }
 
 void FullLetterWidget::btnGroupClickedSlot(QAbstractButton *btn)
@@ -289,7 +309,6 @@ void FullLetterWidget::btnGroupClickedSlot(QAbstractButton *btn)
                 m_scrollAnimation->setStartValue(m_beginPos);
                 m_scrollAnimation->setEndValue(m_endPos);
                 m_scrollAnimation->start();
-
             }
         }
         else{
@@ -352,20 +371,20 @@ void FullLetterWidget::valueChangedSlot(int value)
             index++;
     }
 
-    //向下滚动
-    if((m_buttonList.at(index)->pos().y()+m_buttonList.at(index)->height()+m_letterListScrollArea->widget()->pos().y()) >= m_letterListScrollArea->height())
-    {
-        int val=m_letterListScrollArea->verticalScrollBar()->sliderPosition()+m_buttonList.at(index)->height();
-        m_letterListScrollArea->verticalScrollBar()->setSliderPosition(val);
-    }
+//    //向下滚动
+//    if((m_buttonList.at(index)->pos().y()+m_buttonList.at(index)->height()+m_letterListScrollArea->widget()->pos().y()) >= m_letterListScrollArea->height())
+//    {
+//        int val=m_letterListScrollArea->verticalScrollBar()->sliderPosition()+m_buttonList.at(index)->height();
+//        m_letterListScrollArea->verticalScrollBar()->setSliderPosition(val);
+//    }
 
-    //向上滚动
-    if((m_buttonList.at(index)->pos().y()+m_letterListScrollArea->widget()->pos().y()) <= 0)
-    {
+//    //向上滚动
+//    if((m_buttonList.at(index)->pos().y()+m_letterListScrollArea->widget()->pos().y()) <= 0)
+//    {
 
-        int val=m_letterListScrollArea->verticalScrollBar()->value()-m_buttonList.at(index)->height();
-        m_letterListScrollArea->verticalScrollBar()->setSliderPosition(val);
-    }
+//        int val=m_letterListScrollArea->verticalScrollBar()->value()-m_buttonList.at(index)->height();
+//        m_letterListScrollArea->verticalScrollBar()->setSliderPosition(val);
+//    }
 
 }
 
@@ -397,8 +416,8 @@ void FullLetterWidget::repaintWidget()
     this->setFixedSize(Style::MainViewWidWidth,
                        Style::AppListWidHeight);
     m_applistWid->setFixedSize(Style::AppListWidWidth,this->height());
-    m_letterListWid->setFixedSize(Style::LeftWidWidth,this->height());
     m_scrollArea->setFixedSize(m_applistWid->width(),m_applistWid->height());
+    m_letterListWid->setFixedSize(Style::LeftWidWidth,this->height());
     updateAppListView();
 }
 
@@ -419,9 +438,92 @@ void FullLetterWidget::widgetMakeZero()
 
 void FullLetterWidget::moveScrollBar(int type)
 {
-    int height=QApplication::primaryScreen()->geometry().height();
+    int height=Style::primaryScreenHeight;
     if(type==0)
         m_scrollArea->verticalScrollBar()->setSliderPosition(m_scrollArea->verticalScrollBar()->sliderPosition()-height*100/1080);
     else
         m_scrollArea->verticalScrollBar()->setSliderPosition(m_scrollArea->verticalScrollBar()->sliderPosition()+height*100/1080);
 }
+
+void FullLetterWidget::onSetSlider(int value)
+{
+//    if(flag)
+//    {
+//        flag = false;
+//        time->start(100);
+        int curvalue = m_scrollArea->verticalScrollBar()->value();
+        m_scrollArea->verticalScrollBar()->setValue(curvalue + value);
+//    }
+}
+
+QAbstractButton* FullLetterWidget::getCurLetterButton(int value)
+{
+    return m_buttonList.at(value);
+}
+
+bool FullLetterWidget::eventFilter(QObject *watched, QEvent *event)
+{
+    if( event->type() == QEvent::KeyPress )
+    {
+        QLayoutItem* widItem = m_scrollAreaWidLayout->itemAt(2 * m_buttonList.size() - 1);
+        QWidget* wid = widItem->widget();
+        FullListView* m_listview = qobject_cast<FullListView*>(wid);
+
+        QLayoutItem* widItemTop = m_scrollAreaWidLayout->itemAt(1);
+        QWidget* widTop = widItemTop->widget();
+        FullListView* m_listviewTop = qobject_cast<FullListView*>(widTop);
+
+        QKeyEvent *ke = (QKeyEvent *)event;
+        if( ke->key() == Qt::Key_Tab )
+        {
+           // m_letterListScrollAreaWid->setFocus();
+           // m_letterListScrollArea->setFocus();
+           // return true;
+           Q_EMIT setFocusToSideWin();
+        }
+        if(ke->key() == Qt::Key_Up)
+        {
+            if(!m_listviewTop->hasFocus())
+            {
+                QAbstractButton* buttonTop = getCurLetterButton(( --m_index) % m_buttonList.size());
+                btnGroupClickedSlot(buttonTop);
+                this->m_scrollArea->setFocusToPreChild();
+            }
+            else
+            {
+               m_listview->setFocus();
+               QAbstractButton* button = getCurLetterButton(m_buttonList.size() - 1);
+               btnGroupClickedSlot(button);
+               m_index = m_buttonList.size() - 1;
+            }
+            Q_EMIT selectFirstItem();
+            return true;
+        }
+        if(ke->key() == Qt::Key_Down)
+        {
+            if(!m_listview->hasFocus())
+            {
+                QAbstractButton* button = getCurLetterButton(( ++m_index) % m_buttonList.size());
+                btnGroupClickedSlot(button);
+                this->m_scrollArea->setFocusToNextChild();
+            }
+            else
+            {
+                m_listviewTop->setFocus();
+                QAbstractButton* buttonTop = getCurLetterButton(0);
+                btnGroupClickedSlot(buttonTop);
+                m_index = 0;
+            }
+            Q_EMIT selectFirstItem();
+            return true;
+        }
+    }
+    return QWidget::eventFilter(watched,event);
+}
+
+void FullLetterWidget::letterButtonClick()
+{
+    if(m_btnGroup->button(0)!=nullptr)
+        m_btnGroup->button(0)->click();
+    m_index = 0;
+}
