@@ -37,6 +37,9 @@
 #include "src/Style/style.h"
 #include "src/SideBarWidget/sidebarwidget.h"
 #include "src/MainViewWidget/mainviewwidget.h"
+#include "src/DBus/dbus.h"
+#include "src/DBus/dbus-adaptor.h"
+#include <KWindowEffects>
 
 class MainWindow : public QMainWindow
 {
@@ -48,7 +51,7 @@ public:
     /**
      * @brief Set the QFrame style
      */
-    void setFrameStyle();
+//    void setFrameStyle();
     /**
      * @brief Load the main window
      */
@@ -58,7 +61,6 @@ private:
 
     bool m_isFullScreen=false;
     UkuiMenuInterface *m_ukuiMenuInterface=nullptr;
-    QSettings *m_setting=nullptr;
 
     QFrame *m_line=nullptr;//Vertical dividing line
     QFrame *m_frame=nullptr;
@@ -67,6 +69,7 @@ private:
 
     QPropertyAnimation *m_animation=nullptr;
     bool m_winFlag = false;
+    DBus *m_dbus=nullptr;
 
 protected:
     void initUi();
@@ -74,7 +77,7 @@ protected:
      * @brief Handle events clicking on the outside of the window
      */
     bool event(QEvent *event);
-//    void paintEvent(QPaintEvent*);
+    void paintEvent(QPaintEvent* event);
     /**
      * @brief The query box responds to keyboard events
      */
@@ -84,12 +87,9 @@ protected:
      */
     void repaintWidget();
 
+    void mouseReleaseEvent(QMouseEvent *event);
+
 public Q_SLOTS:
-    /**
-     * @brief Monitor win key events
-     */
-    void XkbEventsPress(const QString &keycode);
-    void XkbEventsRelease(const QString &keycode);
     /**
      * @brief Load the full screen window
      */
@@ -99,16 +99,6 @@ public Q_SLOTS:
      */
     void showDefaultWidget();
     void recvHideMainWindowSlot();//接收隐藏主窗口信号
-    /**
-     * @brief Monitor screen resolution
-     * @param rect: Screen resolution
-     */
-    void monitorResolutionChange(QRect rect);
-    /**
-     * @brief Monitor primary screen changes
-     * @param screen: Primary screen
-     */
-    void primaryScreenChangedSlot(QScreen *screen);
     /**
      * @brief Monitor taskbar key changes
      * @param key: Key
@@ -116,15 +106,13 @@ public Q_SLOTS:
     void panelChangedSlot(QString key);
     void animationValueChangedSlot(const QVariant &value);//动画当前值变化监控
     void animationValueFinishedSlot();
+    void primaryScreenChangeSlot();
+    void activeWindowSolt(bool flag);
+    void mainWinShowSlot();
 
-    /**
-     * @brief Open the start menu by signaling
-     */
-    void recvStartMenuSlot();
-    /**
-     * @brief Monitor win-key-release key value.
-     */
-    void winKeyReleaseSlot(const QString &key);
+public:
+Q_SIGNALS:
+    void setFocusSignal();
 };
 
 #endif // MAINWINDOW_H
