@@ -36,6 +36,7 @@
 #include <QEvent>
 #include "src/Interface/ukuimenuinterface.h"
 #include "src/Style/style.h"
+#include "menubox.h"
 
 class RightClickMenu : public QWidget
 {
@@ -55,25 +56,26 @@ public:
      * @param desktopfp: Application desktop file
      * @return return action number
      */
-    int showAppBtnMenu(QString desktopfp);
+    int showAppBtnMenu(const QPoint &pos, QString desktopfp);
     /**
      * @brief Displays the power right-click menu
      * @return return action number
      */
-    int showShutdownMenu();
+    int showShutdownMenu(const QPoint &pos);
     /**
      * @brief Displays other application right-click menus
      * @param desktopfp: Application desktop file
      * @return return action number
      */
-    int showOtherMenu(QString desktopfp);
+    int showOtherMenu(const QPoint &pos, QString desktopfp);
 
 private:
     QString m_desktopfp;
     int m_actionNumber;
-    QSettings *m_setting=nullptr;
-
     QProcess *m_cmdProc=nullptr;
+    UkuiMenuInterface *m_ukuiMenuInterface=nullptr;
+
+    QStringList m_whiteList;
 
 protected:
     /**
@@ -85,12 +87,6 @@ protected:
      * @return
      */
     QPixmap getIconPixmap(QString iconstr, int type);
-    /**
-     * @brief Process image color
-     * @param source: QPixmap icon
-     * @return return QPixmap icon
-     */
-    QPixmap drawSymbolicColoredPixmap(const QPixmap &source);
 
 private Q_SLOTS:
     /**
@@ -147,10 +143,10 @@ private Q_SLOTS:
      * @brief Personalize this list
      */
     void otherListActionTriggerSlot();
-    /**
-     * @brief Read command output
-     */
-    void onReadOutput();
+
+public:
+Q_SIGNALS:
+    void sendMainWinActiveSignal(bool flag);
 };
 
 #endif // RIGHTCLICKMENU_H
