@@ -42,14 +42,17 @@
 #define RightClickMenuOpacity 0.95
 #define ToolTipBackground "rgba(26, 26, 26, 0.7)"
 #define DefaultBackground "rgba(19, 19, 20, 0.7)" //默认态背景色
-#define LineBackground "rgba(255,255,255,0.06)" //分割线背景色
+#define LineBackground "rgba(255,255,255)" //分割线背景色
 #define SBClassifyBtnSelectedBackground "#3D6BE5" //侧边栏上部分类按钮选择背景
 #define SBFunBtnHoverBackground "rgba(255, 255, 255, 0.14)" //侧边栏目下部功能按钮悬浮背景
 #define ClassifyBtnHoverBackground "rgba(255, 255, 255, 0.14)" //分类按钮悬浮背景
 #define MMBtnHoverBackground "rgba(255, 255, 255, 0.14)" //最大化最小化按钮悬浮背景
-#define QueryLineEditBackground "rgba(0, 0, 0,0.4)" //搜索框背景
-#define QueryLineEditClickedBackground "rgba(0, 0, 0,0.5)" //搜索框背景选中
-#define QueryLineEditClickedBorder "rgba(61, 107, 229, 1)" //搜索框背景选中边框
+#define QueryLineEditDefaultBackground "rgba(0, 0, 0,0.04)" //搜索框默认态背景
+#define QueryLineEditBackground "rgba(255, 255, 255,0.06)" //搜索框背景
+#define QueryLineEditClickedDefaultBackground "rgba(0, 0, 0,0.04)" //搜索框默认态背景选中
+#define QueryLineEditClickedBackground "rgba(255, 255, 255,0.06)" //搜索框背景选中
+#define QueryLineEditClickedBorderDefault "rgba(0, 0, 0,0.1)" //搜索框默认态背景选中边框
+#define QueryLineEditClickedBorder "rgba(255, 255, 255,0.15)" //搜索框背景选中边框
 #define AppBtnHover "#ffffff" //按钮悬浮
 
 /**
@@ -85,6 +88,13 @@ class Style
 public:
     Style();
     static void initWidStyle();
+
+    static int primaryScreenX;
+    static int primaryScreenY;
+    static int primaryScreenWidth;
+    static int primaryScreenHeight;
+    static int panelPosition;
+    static int panelSize;
     //默认窗口
     static int minw;
     static int minh;
