@@ -41,29 +41,36 @@ public:
 
 protected:
     void initWidget();
+    void keyPressEvent(QKeyEvent* e);
     void enterEvent(QEvent* e) Q_DECL_OVERRIDE;
     void leaveEvent(QEvent* e) Q_DECL_OVERRIDE;
-//    void mousePressEvent(QMouseEvent *event);
+    void paintEvent(QPaintEvent *e) override;
+    void focusInEvent(QFocusEvent *event);
+    void focusOutEvent(QFocusEvent *event);
+    void mousePressEvent(QMouseEvent *event);
 
 private:
     FullItemDelegate* m_delegate=nullptr;
     QStandardItemModel* listmodel=nullptr;
     int module=0;
-
+    double transparency;
     RightClickMenu* menu=nullptr;//右键菜单
-    QSettings *setting=nullptr;
     QStringList data;
-
+    QGSettings* gsetting;
     UkuiMenuInterface* pUkuiMenuInterface=nullptr;
 
-private Q_SLOTS:
+//    bool inCurView;
+
+public Q_SLOTS:
     void onClicked(QModelIndex index);//点击item
     void rightClickedSlot(const QPoint &pos);//右键菜单
+    void selectFirstItem();
 
 Q_SIGNALS:
     void sendItemClickedSignal(QString arg);//发送item点击信号
     void sendHideMainWindowSignal();
     void sendUpdateAppListSignal();
+    void sendSetslidebar(int value);
 };
 
 #endif // FULLLISTVIEW_H
