@@ -19,13 +19,13 @@
 #include "itemdelegate.h"
 #include <QPushButton>
 #include <syslog.h>
+#include <QToolTip>
+#include "src/UtilityFunction/utility.h"
 
 ItemDelegate::ItemDelegate(QObject* parent, int module):
     QStyledItemDelegate(parent)
 {
     this->module=module;
-    QString path=QDir::homePath()+"/.config/ukui/ukui-menu.ini";
-    setting=new QSettings(path,QSettings::IniFormat);
     pUkuiMenuInterface=new UkuiMenuInterface;
 
 }
@@ -39,24 +39,12 @@ void ItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
 {
     if(index.isValid())
     {
-        painter->save();
-        QStyleOptionViewItem viewOption(option);//用来在视图中画一个item
+//        QStyleOptionViewItem viewOption(option);//用来在视图中画一个item
         QRectF rect;
-        QStringList strlist1=index.model()->data(index,Qt::DisplayRole).toStringList();
-        if(strlist1.at(1).toInt()==1)
-        {
-            rect.setX(option.rect.x());
-            rect.setY(option.rect.y());
-            rect.setWidth(option.rect.width()-6);
-            rect.setHeight(option.rect.height()-2);
-        }
-        else
-        {
-            rect.setX(option.rect.x());
-            rect.setY(option.rect.y()+2);
-            rect.setWidth(option.rect.width()-6);
-            rect.setHeight(option.rect.height()-6);
-        }
+        rect.setX(option.rect.x());
+        rect.setY(option.rect.y());
+        rect.setWidth(option.rect.width());
+        rect.setHeight(option.rect.height()-2);
 
         //QPainterPath画圆角矩形
         const qreal radius = 4;
@@ -73,16 +61,15 @@ void ItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
 
         QStringList strlist=index.model()->data(index,Qt::DisplayRole).toStringList();
         painter->setRenderHint(QPainter::Antialiasing);
-//        if(option.state.testFlag(QStyle::State_Selected))
-        if(option.state & QStyle::State_MouseOver)
+        if((option.state & QStyle::State_MouseOver) || (option.state & QStyle::State_HasFocus))
         {
+            QColor color = option.palette.text().color();
+            color.setAlphaF(0.15);
+            painter->save();
             painter->setPen(QPen(Qt::NoPen));
-            QColor color;
-            color.setNamedColor(QString::fromLocal8Bit(AppBtnHover));
             painter->setBrush(color);
-            painter->setOpacity(0.14);
             painter->drawPath(path);
-
+            painter->restore();
         }
         painter->setOpacity(1);
 
@@ -111,41 +98,62 @@ void ItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
                             icon=QIcon(QString("/usr/share/icons/hicolor/32x32/apps/%1.%2").arg(iconstr).arg("svg"));
                         else if(QFile::exists(QString("/usr/share/icons/hicolor/32x32/apps/%1.%2").arg(iconstr).arg("png")))
                             icon=QIcon(QString("/usr/share/icons/hicolor/32x32/apps/%1.%2").arg(iconstr).arg("png"));
+                        else if(QFile::exists(QString("/usr/share/pixmaps/%1.%2").arg(iconstr).arg("png")))
+                            icon=QIcon(QString("/usr/share/pixmaps/%1.%2").arg(iconstr).arg("png"));
+                        else if(QFile::exists(QString("/usr/share/pixmaps/%1.%2").arg(iconstr).arg("svg")))
+                            icon=QIcon(QString("/usr/share/pixmaps/%1.%2").arg(iconstr).arg("svg"));
                         else
                             icon=QIcon::fromTheme(QString("application-x-desktop"));
                     }
                 }
+                painter->save();
                 icon.paint(painter,iconRect,Qt::AlignLeft);
-                painter->setPen(QPen(Qt::white));
                 QString appname=pUkuiMenuInterface->getAppName(strlist.at(0));
+                QFontMetrics fm=painter->fontMetrics();
+                QString appnameElidedText=fm.elidedText(appname,Qt::ElideRight,rect.width()-62,Qt::TextShowMnemonic);
                 painter->drawText(QRect(iconRect.right()+15,rect.y(),
-                                        rect.width()-62,rect.height()),Qt::AlignVCenter,appname);
-                setting->beginGroup("recentapp");
+                                        rect.width()-62,rect.height()),Qt::AlignVCenter,appnameElidedText);
+                painter->restore();
+                painter->save();
                 QFileInfo fileInfo(strlist.at(0));
                 QString desktopfn=fileInfo.fileName();
-                if(setting->contains(desktopfn))
+                if(checkIfRecent(desktopfn))
                 {
                     painter->setPen(QPen(Qt::NoPen));
                     painter->setBrush(QColor("#4d94ff"));
                     painter->drawEllipse(QPoint(rect.topRight().x()-22,rect.y()+(rect.height()-8)/2+4),4,4);
                 }
-                setting->endGroup();
+                painter->restore();
+
+                if((option.state & QStyle::State_MouseOver) || (option.state & QStyle::State_HasFocus))
+                {
+                    int len=fm.boundingRect(appname).width();
+                    if(len>rect.width()-62)
+                    {
+                        QToolTip::showText(QCursor::pos(),appname);
+                    }
+                    else {
+                        QToolTip::hideText();
+                    }
+                }
             }
             else
             {
-                painter->setPen(QPen(Qt::white));
-                QRect textRect=QRect(rect.x()+11,rect.y()+12,rect.width(),rect.height());
-                painter->drawText(textRect,Qt::AlignLeft,strlist.at(0));
+                //绘制分割线
+                painter->save();
+//                QRect textRect=QRect(rect.x()+11,rect.y()+12,rect.width(),rect.height());
+                QRect textRect=QRect(rect.x()+11,rect.y(),rect.width(),rect.height());
+                painter->drawText(textRect,Qt::AlignVCenter,strlist.at(0));
                 painter->setRenderHint(QPainter::Antialiasing, true);
-                painter->setPen(QPen(QColor("#FFFFFF"),1));
-                painter->setOpacity(0.06);
+                painter->setPen(QPen(QColor(option.palette.text().color()),1));
+                painter->setOpacity(0.1);
                 painter->drawLine(QPoint(5,rect.bottom()),QPoint(rect.right(),rect.bottom()));
+                painter->restore();
             }
 
         }
         else
         {
-            painter->setOpacity(1);
             QRect iconRect=QRect(rect.left()+11,rect.y()+(rect.height()-32)/2,32,32);
             QString iconstr=pUkuiMenuInterface->getAppIcon(strlist.at(0));
             QIcon icon;
@@ -159,8 +167,6 @@ void ItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
                 icon=QIcon::fromTheme(iconstr);
                 if(icon.isNull())
                 {
-                    if(pUkuiMenuInterface->getAppName(strlist.at(0))=="baidunetdisk")
-                        syslog(LOG_LOCAL0 | LOG_DEBUG ,"---2---");
                     if(QFile::exists(QString("/usr/share/icons/hicolor/scalable/apps/%1.%2").arg(iconstr).arg("svg")))
                         icon=QIcon(QString("/usr/share/icons/hicolor/scalable/apps/%1.%2").arg(iconstr).arg("svg"));
                     else if(QFile::exists(QString("/usr/share/icons/hicolor/scalable/apps/%1.%2").arg(iconstr).arg("png")))
@@ -169,6 +175,10 @@ void ItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
                         icon=QIcon(QString("/usr/share/icons/hicolor/32x32/apps/%1.%2").arg(iconstr).arg("png"));
                     else if(QFile::exists(QString("/usr/share/icons/hicolor/32x32/apps/%1.%2").arg(iconstr).arg("svg")))
                         icon=QIcon(QString("/usr/share/icons/hicolor/32x32/apps/%1.%2").arg(iconstr).arg("svg"));
+                    else if(QFile::exists(QString("/usr/share/pixmaps/%1.%2").arg(iconstr).arg("png")))
+                        icon=QIcon(QString("/usr/share/pixmaps/%1.%2").arg(iconstr).arg("png"));
+                    else if(QFile::exists(QString("/usr/share/pixmaps/%1.%2").arg(iconstr).arg("svg")))
+                        icon=QIcon(QString("/usr/share/pixmaps/%1.%2").arg(iconstr).arg("svg"));
                     else
                         icon=QIcon::fromTheme(QString("application-x-desktop"));
                 }
@@ -177,39 +187,52 @@ void ItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
             QString appname=pUkuiMenuInterface->getAppName(strlist.at(0));
             QFileInfo fileInfo(strlist.at(0));
             QString desktopfn=fileInfo.fileName();
-            bool is_locked=false;
-            setting->beginGroup("lockapplication");
-            if(setting->contains(desktopfn))
+            if(checkIfLocked(desktopfn))
             {
-                is_locked=true;
                 QIcon icon(QString(":/data/img/mainviewwidget/lock.svg"));
-                icon.paint(painter,QRect(rect.topRight().x()-22,rect.y()+(rect.height()-16)/2,16,16));
+                icon.paint(painter,QRect(rect.topRight().x() - 30,rect.y()+(rect.height()-16)/2,16,16));
             }
-            setting->endGroup();
-            setting->beginGroup("recentapp");
-            if(setting->contains(desktopfn) && !is_locked)
+            painter->setOpacity(1);
+            painter->save();
+            if(checkIfRecent(desktopfn) && !checkIfLocked(desktopfn))
             {
                 painter->setPen(QPen(Qt::NoPen));
                 painter->setBrush(QColor("#4d94ff"));
-                painter->drawEllipse(QPoint(rect.topRight().x()-22,rect.y()+(rect.height()-8)/2+4),4,4);
+                painter->drawEllipse(QPoint(rect.topRight().x() - 30,rect.y()+(rect.height()-8)/2+4),4,4);
             }
-            setting->endGroup();
+            painter->restore();
+            painter->save();
+            painter->setPen(QPen(option.palette.text().color()));
+            painter->setBrush(Qt::NoBrush);
             painter->setOpacity(1);
-            painter->setPen(QPen(Qt::white));
+            QFontMetrics fm=painter->fontMetrics();
+            QString appnameElidedText=fm.elidedText(appname,Qt::ElideRight,rect.width()-62,Qt::TextShowMnemonic);
             painter->drawText(QRect(iconRect.right()+15,rect.y(),
-                                    rect.width()-62,rect.height()),Qt::AlignVCenter,appname);
+                                    rect.width()-62,rect.height()),Qt::AlignVCenter,appnameElidedText);
+            painter->restore();
+
+            if((option.state & QStyle::State_MouseOver) || (option.state & QStyle::State_HasFocus))
+            {
+                int len=fm.boundingRect(appname).width();
+                if(len>rect.width()-62)
+                {
+                    QToolTip::showText(QCursor::pos(),appname);
+                }
+                else {
+                    QToolTip::hideText();
+                }
+            }
         }
-        painter->restore();
     }
 
 }
 
 QSize ItemDelegate::sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
-    QStringList strlist=index.model()->data(index,Qt::DisplayRole).toStringList();
-    if(strlist.at(1).toInt()==1)
+//    QStringList strlist=index.model()->data(index,Qt::DisplayRole).toStringList();
+//    if(strlist.at(1).toInt()==1)
         return QSize(310,44);
-    else
-        return QSize(310,48);
+//    else
+//        return QSize(310,48);
 
 }
