@@ -17,7 +17,9 @@
  */
 
 #include "listview.h"
+#include "utility.h"
 #include <QDebug>
+#include <QDrag>
 
 ListView::ListView(QWidget *parent, int width, int height, int module):
     QListView(parent)
@@ -29,10 +31,6 @@ ListView::ListView(QWidget *parent, int width, int height, int module):
 
     pUkuiMenuInterface=new UkuiMenuInterface;
     menu=new RightClickMenu;
-
-    QString path=QDir::homePath()+"/.config/ukui/ukui-menu.ini";
-    setting=new QSettings(path,QSettings::IniFormat);
-
 }
 ListView::~ListView()
 {
@@ -42,32 +40,27 @@ ListView::~ListView()
 
 void ListView::initWidget()
 {
-//    this->setFixedSize(w,h);
-
-    this->verticalScrollBar()->setStyleSheet("QScrollBar{padding-top:0px;padding-bottom:0px;background:transparent;width:3px;border-radius:1.5px;}"
-                                             "QScrollBar::handle{background-color:rgba(255,255,255,0.25); width:3px;border-radius:1.5px;}"
-                                             "QScrollBar::handle:hover{background-color:#697883;width:3px;border-radius:1.5px;}"
-                                             "QScrollBar::handle:pressed{background-color:#8897a3;width:3px;border-radius:1.5px;}"
-                                             "QScrollBar::sub-line{background-color:transparent;height:0px;width:0px;}"
-                                             "QScrollBar::add-line{background-color:transparent;height:0px;width:0px;}"
-                                             );
+    setAttribute(Qt::WA_TranslucentBackground);
+    viewport()->setAttribute(Qt::WA_TranslucentBackground);
     this->setSelectionMode(QAbstractItemView::SingleSelection);
     this->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
     this->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-//    this->setGridSize(QSize(310,48));
     this->setResizeMode(QListView::Adjust);
     this->setTextElideMode(Qt::ElideRight);
     this->setViewMode(QListView::ListMode);
     this->setContextMenuPolicy(Qt::CustomContextMenu);
-    this->setFocusPolicy(Qt::NoFocus);
-    this->setMovement(QListView::Static);
+    this->setFocusPolicy(Qt::StrongFocus);
+    this->setMovement(QListView::Free);
+    this->setDragEnabled(QListView::Free);
     this->setEditTriggers(QAbstractItemView::NoEditTriggers);
     this->setUpdatesEnabled(true);
-//    this->setVerticalScrollMode(QAbstractItemView::ScrollPerPixel);
     this->setSpacing(0);
     this->setContentsMargins(0, 0, 0, 0);
     this->setMouseTracking(true);
     this->verticalScrollBar()->setContextMenuPolicy(Qt::NoContextMenu);
+    this->setFrameShape(QFrame::NoFrame);
+    this->verticalScrollBar()->setProperty("drawScrollBarGroove",false);
+    this->setFocus();
     connect(this,&ListView::customContextMenuRequested,this,&ListView::rightClickedSlot);
     connect(this,&ListView::clicked,this,&ListView::onClicked);
 }
@@ -103,31 +96,21 @@ void ListView::onClicked(QModelIndex index)
      QVariant var = listmodel->data(index, Qt::DisplayRole);
      if(var.isValid())
      {
-         QString valstr=var.value<QStringList>().at(1);
-         if(valstr.toInt()==1)
-         {
-             QString desktopfp=var.value<QStringList>().at(0);
-             QFileInfo fileInfo(desktopfp);
-             QString desktopfn=fileInfo.fileName();
-             setting->beginGroup("recentapp");
-             setting->remove(desktopfn);
-             setting->sync();
-             setting->endGroup();
-         }
          Q_EMIT sendItemClickedSignal(var.value<QStringList>());
      }
 }
 
-void ListView::rightClickedSlot()
+void ListView::rightClickedSlot(const QPoint &pos)
 {
     if(!this->selectionModel()->selectedIndexes().isEmpty())
     {
         QModelIndex index=this->currentIndex();
+//        QRect center = visualRect(index);
         QVariant var=listmodel->data(index, Qt::DisplayRole);
         QStringList strlist=var.value<QStringList>();
         if(strlist.at(1).toInt()==1)
         {
-            int ret=menu->showAppBtnMenu(strlist.at(0));
+            int ret = menu->showAppBtnMenu(this->mapToGlobal(pos), strlist.at(0));
             if(module>0)
             {
                 if(strlist.at(1).toInt()==1)
@@ -163,14 +146,25 @@ void ListView::rightClickedSlot()
                 }
             }
 
-            this->selectionModel()->clear();
+          //  this->selectionModel()->clear();
         }
     }
 }
 
+void ListView::dragMoveEvent(QDragMoveEvent *e)
+{
+    Q_UNUSED(e);
+}
+
+void ListView::dropEvent(QDropEvent *e)
+{
+    Q_UNUSED(e);
+}
+
 void ListView::enterEvent(QEvent *e)
 {
     Q_UNUSED(e);
+    this->selectionModel()->clear();
     this->verticalScrollBar()->setVisible(true);
 }
 
@@ -179,3 +173,86 @@ void ListView::leaveEvent(QEvent *e)
     Q_UNUSED(e);
     this->verticalScrollBar()->setVisible(false);
 }
+
+void ListView::paintEvent(QPaintEvent *e)
+{
+    double transparency=getTransparency();
+    QPainter painter(this->viewport());
+    painter.setOpacity(transparency);
+    painter.setPen(Qt::NoPen);
+    painter.setBrush(this->palette().base());
+    painter.fillRect(this->rect(), this->palette().base());
+
+    //滚动条
+    QPalette p=this->verticalScrollBar()->palette();
+    QColor color(255, 255, 255);
+//    QColor color=p.color(QPalette::Active,QPalette::Button);
+    color.setAlphaF(0.25);
+    p.setColor(QPalette::Active,QPalette::Button,color);
+    this->verticalScrollBar()->setPalette(p);
+    QListView::paintEvent(e);
+}
+
+void ListView::dragLeaveEvent(QDragLeaveEvent *e)
+{
+    QVariant pressApp = listmodel->data(this->indexAt(startPos), Qt::DisplayRole);
+    QStringList m_desktopfp = pressApp.value<QStringList>();
+    QString path = QStandardPaths::writableLocation(QStandardPaths::DesktopLocation);
+    QFileInfo fileInfo(m_desktopfp.at(0));
+    QString desktopfn=fileInfo.fileName();
+    QFile file(m_desktopfp.at(0));
+    QString newname=QString(path+"/"+desktopfn);
+    bool ret=file.copy(QString(path+"/"+desktopfn));
+    if(ret)
+    {
+        char command[200];
+        sprintf(command,"chmod a+x %s",newname.toLocal8Bit().data());
+        QProcess::startDetached(QString::fromLocal8Bit(command));
+    }
+}
+
+void ListView::mousePressEvent(QMouseEvent *event)
+{
+    startPos = event->pos();
+    return QListView::mousePressEvent(event);
+}
+
+void ListView::keyPressEvent(QKeyEvent* e)
+{
+    if(e->type()==QEvent::KeyPress)
+    {
+        switch(e->key())
+        {
+        case Qt::Key_Enter:
+        case Qt::Key_Return:
+        {
+            QModelIndex index=this->currentIndex();
+            Q_EMIT clicked(index);
+        }
+            break;
+        case Qt::Key_Down:
+        {
+            if(currentIndex().row() == this->model()->rowCount() - 1)
+            {
+                setCurrentIndex(this->model()->index(0,0));
+                break;
+            }
+            return QListView::keyPressEvent(e);
+            break;
+        }
+        case Qt::Key_Up:
+        {
+            if(currentIndex().row() == 0)
+            {
+                setCurrentIndex(this->model()->index(this->model()->rowCount()-1,0));
+                break;
+            }
+            return QListView::keyPressEvent(e);
+            break;
+        }
+        default:
+            return QListView::keyPressEvent(e);
+            break;
+        }
+    }
+}
