@@ -45,6 +45,12 @@ protected:
     void initWidget();
     void enterEvent(QEvent* e) Q_DECL_OVERRIDE;
     void leaveEvent(QEvent* e) Q_DECL_OVERRIDE;
+    void paintEvent(QPaintEvent *e) override;
+    void keyPressEvent(QKeyEvent* e);
+    void dropEvent(QDropEvent *event);
+    void mousePressEvent(QMouseEvent *event);
+    void dragLeaveEvent(QDragLeaveEvent *e);
+    void dragMoveEvent(QDragMoveEvent *event);
 
 private:
     QStandardItemModel* listmodel=nullptr;
@@ -54,13 +60,17 @@ private:
     UkuiMenuInterface* pUkuiMenuInterface=nullptr;
 
     RightClickMenu* menu=nullptr;//右键菜单
-    QSettings *setting=nullptr;
     QVector<QStringList> data;
     ItemDelegate* m_delegate=nullptr;
+    int m_preRowCount;
+    QPoint startPos;
+//    QMimeData *mimeData = nullptr;
+//    QDrag *drag = nullptr;
+
 
 private Q_SLOTS:
     void onClicked(QModelIndex index);//点击item
-    void rightClickedSlot();//右键菜单
+    void rightClickedSlot(const QPoint &pos);//右键菜单
 Q_SIGNALS:
     void sendItemClickedSignal(QStringList arg);//发送item点击信号
     void sendHideMainWindowSignal();
